
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				10/07/2021
Last update: 		05/02/2024
================================================================================================

GHGE_DATA.DO

Description: This dofile selects sectors and years from CAIT GHGE database to be used to construct the new estimates and reclassifies sectors according to the harmonized classification CAIT-OECD-SEDLAC.

* Source: https://www.climatewatchdata.org/data-explorer/
* Data version Oct 6th, 2021.

==============================================================================================*/


/*==============================================================================================
	1 - GHG Emissions data, 2015, all countries
==============================================================================================*/

* Import data
import excel "${base_in_1}", sheet("CW_Emissions_CAIT_2018") firstrow case(lower) clear

* Keep country, emissions sector, gas type, and 2015 only.
keep country sector gas ad
ren ad year_2015

* Keep only All GHG category
drop if gas != "All GHG"
drop gas

* Keep sectors of interest and recode them using the harmonized CAIT-OECD-SEDLAC classification
encode sector, gen(cross_sector)
drop if inlist(cross_sector,5,2,8,3)
recode cross_sector (1 = 1) (6 = 2) (7 9 = 3) (4 14 = 4) (13 = 6) (10 = 13) (11 = 15) (12 = 16)

#delimit ;
la def sectors 
1  "Agriculture, hunting, forestry and fishing" 
2  "Mining and quarrying" 
3  "Manufacturing, Construction & Industrial processes" 
4  "Electricity, gas and water supply" 
5  "Wholesale and retail trade" 
6  "Transport, storage and communications" 
7  "Hotels and restaurants" 
8  "Financial intermediation" 
9  "Real estate, renting and business activities" 
10 "Public administration and defence" 
11 "Education" 
12 "Health and social work" 
13 "Other community, social and personal service activities" 
14 "Activities of private households as employers" ;
la val cross_sector sectors ;
drop sector;
#delimit cr

* Add data by harmonized sectors and countries.
collapse (sum) year_2015, by(country cross_sector)

* Generate variables with total GHGE and the residual
gen total_ghg = year_2015 if cross_sector == 16 // Total GHGE with LUCF
bysort country: egen ghg = total(total_ghg)
drop if cross_sector == 16
drop total_ghg

gen total_ghg = year_2015 if cross_sector == 15 // Total GHGE with LUCF
bysort country: egen ghg_excLUCF = total(total_ghg)
drop if cross_sector == 15
drop total_ghg

bysort country: egen total_ghg = total(year_2015)
gen ghg_other = ghg - total_ghg
gen ghg_excLUCF_other = ghg_excLUCF - total_ghg
drop total_ghg

* Labelling
la var year_2015 "GHG Emissions"
la var ghg "GHG Total Emissions - All sectors"
la var ghg_excLUCF "GHG Total Emissions - Excluding LUCF"
la var ghg_other "GHG Emissions other industries"
la var ghg_excLUCF_other "GHG Emissions other industries - Excluding LUCF"

* Save the data
compress
save "${base_in_2}", replace


/*==============================================================================================
	2 - GHG Emission data for 2005 - 2018
==============================================================================================*/

* Import data
import excel "${base_in_1}", sheet("CW_Emissions_CAIT_2018") firstrow case(lower) clear

* Keep country, emissions sector, gas type, and years of analysis (2005 to 2018).
keep country sector gas t-ag
ren (t u v w x y z aa ab ac ad ae af ag) (yr2005 yr2006 yr2007 yr2008 yr2009 yr2010 yr2011 yr2012 yr2013 yr2014 yr2015 yr2016 yr2017 yr2018)

* Keep only All GHG category
drop if gas != "All GHG"
drop gas

* Keep sectors of interest and recode them using the harmonized CAIT-OECD-SEDLAC classification
encode sector, gen(cross_sector)
drop if inlist(cross_sector,12,5,2,8,3)
recode cross_sector (1 = 1) (6 = 2) (7 9 = 3) (4 14 = 4) (13 = 6) (10 = 13) (11 = 15)

#delimit ;
la def sectors 
1  "Agriculture, hunting, forestry and fishing" 
2  "Mining and quarrying" 
3  "Manufacturing, Construction & Industrial processes" 
4  "Electricity, gas and water supply" 
5  "Wholesale and retail trade" 
6  "Transport, storage and communications" 
7  "Hotels and restaurants" 
8  "Financial intermediation" 
9  "Real estate, renting and business activities" 
10 "Public administration and defence" 
11 "Education" 
12 "Health and social work" 
13 "Other community, social and personal service activities" 
14 "Activities of private households as employers" ;
la val cross_sector sectors;
drop sector;
#delimit cr

* Add annual data by harmonized sectors and countries.
collapse (sum) yr*, by(country cross_sector)

* Convert data to long (years)
reshape long yr, i(country cross_sector) j(year)
ren yr ghg_emissions

* Generate variables with total GHGE and the residual
gen total_ghg = ghg_emissions if cross_sector == 15
bysort country year: egen ghg = total(total_ghg)
drop if cross_sector == 15
drop total_ghg

bysort country year: egen total_ghg = total(ghg_emissions)
gen ghg_other = ghg - total_ghg
drop total_ghg

* Labelling
la var ghg_emissions "GHG Emissions"
la var ghg "GHG Total Emissions - All sectors"
la var ghg_other "GHG Emissions other industries"

* Save the data
compress
save "${base_in_3}", replace

/*==============================================================================================
  - END
==============================================================================================*/