
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				11/15/2021
Last update: 		05/02/2024
================================================================================================

GHGE_ESTIMATION_LAC.DO

Description: This dofiles estimates the new GHGE using OCDE OITs for LAC countries only, generates technology coefficients, sectors' shares in total emissions, and final demand vectors.

* Source: Input-Output Tables (IOTs) 2018 ed. https://stats.oecd.org/Index.aspx?DataSetCode=IOTSI4_2018#
* Data version Oct 8, 2021 for 2015 IOTs and Nov 15, 2021 for the other years.

==============================================================================================*/

* Set output file empty
clear
save "${base_out_3}", emptyok replace


/*==============================================================================================
	1 - Technology coefficients using IOTs by country and year
==============================================================================================*/

* Latin America countries to include in the analysis
local countries ARG BRA CHL COL CRI MEX PER

* Years availability by source
local years_ghg 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 // GHGE CAIT
local years_io  2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2015 2015 2015 // OECD IOTs

local n : word count `years_ghg'
foreach country of local countries {
    
	forvalues i = 1/`n'  {
	    
		local year_ghg : word `i' of `years_ghg'
		local year_io : word `i' of `years_io'
		di in red "GHG: `year_ghg', IO: `year_io'"
	    
		di in red "`country' - `year_ghg'"
		
		* Import country IOT
		qui import excel "${data}\oecd\iots\IO_`country'_`year_io'.xlsx", sheet("OECD.Stat export") clear
		
		* Drop categories that do not correspond to sectors
		keep A C-AU
		qui drop in 1/6 // Heading
		qui drop if regexm(A,"Taxes") | regexm(A,"OECD.Stat") | regexm(A,"Value added") | regexm(A,"intermediate consumption") // Not economic sectors
		
		* Extracting sectors code and name
		qui gen sector_code = substr(A, strpos(A,"_") + 1, strpos(A,":") - 5)
		qui gen sector_name = substr(A, strpos(A,"_") + 1, strpos(A,":") - 5)
		
		foreach v of varlist C-AL {
		    qui replace `v' = substr(`v',1,strpos(`v',":") - 1) in 1
			rename `v' `=`v'[1]'
		}
		
		qui drop in 1/2
		drop A
		order sector_code
		
		* Destring production variables
		qui destring D*, replace
		qui destring AM-AU, replace
		
		* Generate auxiliar variables
		egen gross_product = rowtotal(D01T03-AU)
		egen intermediate_demand = rowtotal(D01T03-D97T98)
		egen final_demand = rowtotal(AM-AQ AS AT)
		drop AM-AU

		*Sectors (cross-classification)
		egen sector1 = rowtotal(D01T03) 					// Agriculture
		egen sector2 = rowtotal(D05T06 D07T08 D09) 			// Mining
		egen sector3 = rowtotal(D10T12 D13T15 D16 D17T18 D19 D20T21 D22 D23 D24 D25 D26 D27 D28 D29 D30 D31T33 D41T43) 				// Manufacturing
		egen sector4 = rowtotal(D35T39) 					// Electricity
		egen sector5 = rowtotal(D45T47) 					// Retail
		egen sector6 = rowtotal(D49T53 D58T60 D61 D62T63) 	// Transport
		egen sector7 = rowtotal(D55T56) 					// Hotels and restaurants
		egen sector8= rowtotal(D64T66) 						// Financial intermediation
		egen sector9 = rowtotal(D68 D69T82) 				// Real estate
		egen sector10 = rowtotal(D84) 						// Public administration
		egen sector11 = rowtotal(D85) 						// Education
		egen sector12 = rowtotal(D86T88) 					// Health and social work
		egen sector13 = rowtotal(D90T96) 					// Other community
		egen sector14 = rowtotal(D97T98) 					// Private households
	
		qui gen cross_sector = .
		qui replace cross_sector = 1 	if inlist(sector_code,"01T03")
		qui replace cross_sector = 2 	if inlist(sector_code,"05T06","07T08","09")
		qui replace cross_sector = 3 	if inlist(sector_code,"10T12","13T15","16","17T18","19","20T21","22","23")
		qui replace cross_sector = 3 	if inlist(sector_code,"24","25","26","27","28","29","30","31T33","41T43")
		qui replace cross_sector = 4 	if inlist(sector_code,"35T39")
		qui replace cross_sector = 5 	if inlist(sector_code,"45T47")
		qui replace cross_sector = 6 	if inlist(sector_code,"49T53","58T60","61","62T63")
		qui replace cross_sector = 7 	if inlist(sector_code,"55T56")
		qui replace cross_sector = 8 	if inlist(sector_code,"64T66")
		qui replace cross_sector = 9 	if inlist(sector_code,"68","69T82")
		qui replace cross_sector = 10 	if inlist(sector_code,"84")
		qui replace cross_sector = 11 	if inlist(sector_code,"85")
		qui replace cross_sector = 12 	if inlist(sector_code,"86T88")
		qui replace cross_sector = 13 	if inlist(sector_code,"90T96")
		qui replace cross_sector = 14 	if inlist(sector_code,"97T98")
		
		* Add production by harmonized sectors' classification
		collapse (sum) sector1-sector14 gross_product intermediate_demand final_demand, by(cross_sector)
		
		* Creating technology coefficients
		foreach v of varlist sector1-sector14{
			qui replace `v' = `v'/`v'[_N] if `v'[_N] != 0
		}
	
		qui drop if cross_sector == .
		
		* National production and its share
		egen nat_prod = total(gross_product)
		gen share_nat_prod = gross_product / nat_prod
		
		* Matrix "M" of the model
		mkmat sector1-sector14, matrix(A) rownames(cross_sector)
		matrix M = inv(I(14) - A)
		
		* Country and year ID to merge with GHGEs.
		gen country = "`country'"
		gen year = `year_ghg'
		
		* Merge with GHGEs.
		qui merge 1:1 country year cross_sector using "${base_in_3}", keep(1 3) nogenerate
		
		* Fill data gaps for sectors not available in GHGEs data.
		qui sum ghg
		qui replace ghg = r(mean) if ghg == . 
		qui sum ghg_other
		qui replace ghg_other = r(mean) if ghg_other == . 
		qui replace ghg_emissions = share_nat_prod * ghg_other if ghg_emissions == . // For sectors without information on ghg emission (See https://www.inegi.org.mx/contenidos/eventos/2013/taip/R-PabloRuiz.pdf)
		
		* Generate emission multiplier, vector "c" of the model
		qui gen emissions_multip = ghg_emissions / gross_product
		qui replace emissions_multip = 0 if emissions_multip == .
		mkmat emissions_multip, matrix(c1) rownames(cross_sector)
	
		matrix c = diag(c1)
		
		* New vector of estimated emissions
		matrix C = c * M
		mkmat final_demand, matrix(y_total) rownames(cross_sector)
		qui la val cross_sector sectors
		matrix emissions = C * y_total
		svmat emissions 
		
		* Add labels
		la var sector1 	"Agriculture, hunting, forestry and fishing" 
		la var sector2 	"Mining and quarrying" 
		la var sector3 	"Manufacturing, Construction & Industrial processes" 
		la var sector4 	"Electricity, gas and water supply" 
		la var sector5 	"Wholesale and retail trade" 
		la var sector6 	"Transport, storage and communications" 
		la var sector7 	"Hotels and restaurants" 
		la var sector8 	"Financial intermediation" 
		la var sector9 	"Real estate, renting and business activities" 
		la var sector10 "Public administration and defence" 
		la var sector11 "Education" 
		la var sector12 "Health and social work" 
		la var sector13 "Other community, social and personal service activities" 
		la var sector14 "Activities of private households as employers"

		* Append data and save
		qui compress
		qui append using "${base_out_3}"
		qui save "${base_out_3}", replace

	}
}

* Keep only the estimated emissions vector
keep country year cross_sector emissions1

* Save the data
qui save "${base_out_3}", replace

/*==============================================================================================
  - END
==============================================================================================*/