
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				11/15/2021
Last update: 		05/02/2024
================================================================================================

EMISSIONS_PER_WORKER.DO

Description: This dofile estimates the number of emissions per worker and classifies the economic sectors into green and not green according to their level of emissions per worker.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/

* Set output file empty
clear
save "${base_in_6}", emptyok replace
save "${base_in_7}", emptyok replace


/*==============================================================================================
	1 - Workers per sector
==============================================================================================*/

* Latin America countries to include in the analysis
local countries ARG BRA CHL COL CRI MEX PER

foreach country of local countries { // Open loop countries
	
	foreach year of numlist 2005/2019 { // Open loop year
		
		* Loading the data
		
		di in red "`country' - `year'"
				
		if "`country'" == "ARG" & `year' == 2015 continue // ARG 2015 S2 not available.
		
		else if "`country'" == "ARG" qui dlw, country("`country'") year(`year') type(sedlac) period(s2) mod(all) clear // We use period S2 for Argentina
			
		else if ("`country'" == "BRA" & `year' < 2012) continue // Variable isco08_2d is not available for BRA before 2012. 
		
		else if ("`country'" == "BRA" & `year' >= 2012) qui dlw, country("`country'") year(`year') type(sedlac) mod(pov lab edu) survey(pnadc) clear // BRA has 2 surveys between 2012 and 2015, we use PNADC.
		
		else if ("`country'" == "CHL" & !inlist(`year',2006,2009,2011,2013,2015,2017)) continue // No survey available for these years.
		
		else if ("`country'" == "CHL" & inlist(`year',2011,2013,2015,2017)) qui dlw, country("`country'") year(`year') type(sedlac) mod(pov lab edu) clear // Some years from CHL do not load "all" module, only "pov lab edu" are necessary.
		
		else if "`country'" == "COL" & `year' < 2011 continue // Variable isco08_2d is not available for COL before 2011.
		
		else if "`country'" == "COL" qui dlw, country("`country'") year(`year') type(sedlac) mod(pov lab edu) clear  // COL does not load "all" module, only "pov lab edu" are necessary.
		
		else if "`country'" == "CRI" & `year' < 2012 continue // Variable isco08_2d is not available for CRI before 2012.
		
		else if "`country'" == "MEX" & `year' < 2012 continue // Variable isco08_2d is not available for MEX before 2012.
		
		else if "`country'" == "MEX" & inlist(`year',2013,2015,2017,2019) continue // No survey available for MEX on these years.
		
		else if "`country'" == "PER" & `year' < 2016 continue // Variable isco08_2d is not available for PER before 2016.
	
		else qui dlw, country("`country'") year(`year') type(sedlac) mod(all) clear
		
		* REMINDER: Always filter for coherent households.
		qui keep if cohh == 1 & ipcf!=. // Poverty analysis is made only with hhs with nonmissing family income

		* Demographics
		qui gen n = 1

		* Economic sector (according to GHG emissions). In some cases sector1d is missing, then create missing variables.
		qui count if sector1d != .
		if r(N) != 0 { 
			qui gen 	cross_sector = 1 if (inrange(sector1d,1,2))	// Agriculture, hunting, forestry and fishing
			qui replace cross_sector = 2 if sector1d == 3			// Mining and quarrying
			qui replace cross_sector = 3 if inlist(sector1d,4,6) 	// Manufacturing, Construction & Industrial processes
			qui replace cross_sector = 4 if sector1d == 5			// Electricity, gas and water supply
			qui replace cross_sector = 5 if sector1d == 7			// Wholesale and retail trade
			qui replace cross_sector = 6 if sector1d == 9			// Transport, storage and communications
			qui replace cross_sector = 7 if sector1d == 8			// Hotels and restaurants
			qui replace cross_sector = 8 if sector1d == 10			// Financial intermediation
			qui replace cross_sector = 9 if sector1d == 11			// Real estate, renting and business activities
			qui replace cross_sector = 10 if sector1d == 12			// Public administration and defence
			qui replace cross_sector = 11 if sector1d == 13			// Education
			qui replace cross_sector = 12 if sector1d == 14			// Health and social work
			qui replace cross_sector = 13 if sector1d == 15			// Other community, social and personal service activities
			qui replace cross_sector = 14 if sector1d == 16			// Activities of private households as employers
		}
		else { // Some countries don't have sector defined (BOL 2000)
			qui gen cross_sector = .
		}
			
		* Workers populations by sector
		preserve
			collapse (first) pais ano (sum) n [fw=pondera] if ocupado == 1 & inrange(edad,15,64) & isco08_2d != ., by(cross_sector)
			append using "${base_in_6}"
			qui save "${base_in_6}", replace
		restore
		
		* Workers populations by ISCO
		preserve
			collapse (first) pais ano (sum) n [fw=pondera] if ocupado == 1 & inrange(edad,15,64) & isco08_2d != ., by(isco08_2d)
			append using "${base_in_7}"
			qui save "${base_in_7}", replace
		restore

		
	} // Close loop year
	
} // Close loop countries


* Organize the sectoral database
use "${base_in_6}", clear
duplicates drop // in case the loop stopped halfway for internet conection.
drop if cross_sector == .	
ren (pais ano n) (country year workers)
save "${base_in_6}", replace


/*==============================================================================================
	2 - Emissions per worker per sector
==============================================================================================*/

* Load the data
use "${base_out_3}", clear

* Emissions are in Mt, I convert them to tonnes
replace emissions1 = emissions1 * 1000000
replace country=lower(country)

* Merge with workers per sector
merge 1:1 country year cross_sector using "${base_in_6}", keep(3) nogenerate

* Emissions per worker
gen emiss_per_wkr = emissions / workers

* Keep necessary variables
keep country year cross_sector emiss_per_wkr

* Labels
la var country 			"Country"
la var year 			"Year"
la var emiss_per_wkr 	"Emissions per worker" 
la var cross_sector 	"Sector"

* Country in upper case
replace country = upper(country)

* Saving
compress
save "${base_out_4}", replace

/*==============================================================================================
	3 - Sectors ranking using median of emissions per worker
==============================================================================================*/

* Load the emissions per worker data
use "${base_out_4}", clear

* Sectors' ranking and classification using median of emissions per worker
egen rank=rank(emiss_per_wkr), by(country year)
gen 	classification = "Pollutant" if inrange(rank,8,14)
replace classification = "Green" if inrange(rank,1,7)
keep country year cross_sector classification

forvalues i=1/14 {
	di in red "`i'"
	ta classification if cross_sector == `i'
	ta year classification if cross_sector == `i'
	ta country if cross_sector == `i' & classification == "Green"
}

/* Sector classification for the whole series
sector 8 defined as pollutant (only ARG green)
sector 9 defined as green (ARG and some years of CRI no green)

sector 1 pollutant
sector 2 pollutant
sector 3 pollutant
sector 4 pollutant
sector 5 green
sector 6 pollutant
sector 7 green
sector 8 pollutant, green for ARG 2006, 2008/2014, 2017/2018
sector 9 green, pollutant for ARG 2006, 2008/2014, 2017/2018
sector 10 green
sector 11 green
sector 12 green
sector 13 pollutant
sector 14 green
*/


* Table 7 – Green (green color) and non-green (brown color) sectors
reshape wide classification, i(cross_sector country) j(year)
sort cross_sector country
la var cross_sector	"Sector"
la var country 		"Country"
for any 05 06 07 08 09 10 11 12 13 14 15 16 17 18: la var classification20X "X"
export excel using "${table_7}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

/*==============================================================================================
  - END
==============================================================================================*/