
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

GREEN_OCC.DO

Description: Generates databases with green occupations at the ISCO-08 different digit levels of aggregation.

==============================================================================================*/


/*==============================================================================================
	1 - Preparing Green Occupations' Database
==============================================================================================*/

* Loads O*NET green occupations database
import excel using "${base_in_8}", first clear

* Rename variables
rename ONETSOCCode soc8d
rename GreenOccupationalCategory green_category
rename Title green_title

* Counting occupations by type (62 ES, 64 ID, 78 N&E, and 204 total) 
ta green_category, m

* Generates 6-digits SOC code
gen soc=substr(soc8d,1,7)
destring soc, ignore("-") replace

* Sorting and saving as a temporal database
sort soc8d
tempfile green
save "`green'", replace


/*==============================================================================================
	2 - Preparing Rival Occupations' Database
==============================================================================================*/

* Loads related occupations database (Vol. II Allen et al. 2012)
import excel using "${base_in_9}", first clear

* Rename variables
rename TargetCode soc8d 

* Counting referred occupations at a 8-digits level (858)
preserve
	keep soc8d TargetOccupation
	duplicates drop
	count
restore

* Sorting and saving as a temporal database
sort soc8d
tempfile related_occ
save "`related_occ'", replace


/*==============================================================================================
	3 - Preparing Final Occupations' Database
==============================================================================================*/

* Loads the list of O*NET-SOC 2010 occupations at a 8-digits level (the full list is loaded since the green occupations' database does not have non-green occupations)
import excel using "${base_in_10}", first clear

* Rename variables
rename ONETSOC2010Code soc8d
rename ONETSOC2010Title soc8d_title
rename ONETSOC2010Description soc8d_des

* Generating 6-digits SOC code
gen soc=substr(soc8d,1,7)
destring soc, ignore("-") replace

* Indicator variable for occupations with more than one 8-digit SOC code within a 6-digit SOC code
egen n8d_within6d =count(soc8d), by(soc)
gen more_than_1_8d = (n8d_within6d>1 & n8d_within6d<.)
label var more_than_1_8d "1 = More than 1 8-digit soc within 6-digit SOC" 
label var n8d_within6d   "Number of 8-digit soc within 6-digit SOC" 

* Characterizing SOC at the 6-digits level
count
ta more_than_1_8d, m

* Sorting and saving as a temporal database
sort soc8d
tempfile list_occ
save "`list_occ'", replace


/*==============================================================================================
	4 - Joining Occupations List with Green and Rival Occupations Databases ==============================================================================================*/

* Joining green occupations at the 8-digits SOC level
sort soc8d
merge soc8d using "`green'"
ta _merge
drop _merge

* Joining rival occupations at the 8-digits SOC level 
sort soc8d
merge soc8d using "`related_occ'"
ta _merge
* Note: The "Careers starters and changers" list does not have many N&E (54). It has all the mentioned ID and ES (except for 1) and does not have 197 non-green occupations (i.g. legislators) 
ta green_category _merge, m
drop _merge

* Temporarily renames and joins "Career starters and changers" to green categories
rename soc8d soc8d_original
rename green_category green_category_original
rename green_title green_title_original
rename soc soc_original

	** Career changers 
	rename ChangeCode soc8d
	sort soc8d
	merge soc8d using "`green'"
	ta _merge
	drop if _merge==2
	drop _merge
	rename soc8d soc8d_changers
	rename green_category green_category_changers
	rename green_title green_title_changers
	rename soc soc_changers

	** Career starters 
	rename StarterCode soc8d
	sort soc8d
	merge soc8d using "`green'"
	ta _merge
	drop if _merge==2
	drop _merge
	rename soc8d soc8d_starters
	rename green_category green_category_starters
	rename green_title green_title_starters
	rename soc soc_starters

* Returning to original variables
rename soc8d_original soc8d
rename green_category_original green_category
rename green_title_original green_title 
rename soc_original soc
sort soc8d

* Generating indicator variable for rival non-green and other non-green following Bowen et al, 2018.
* Indicator for any occupation green-related
gen aux = 1 if green_title_changers!="" | green_title_starters!=""
egen green_related = max(aux), by(soc8d)
replace green_category = "Green Rival"     if green_category == "" & green_related==1
replace green_category = "Other Non-green" if green_category == "" & green_related==.

* Preserving one observation by 8-digits SOC code
keep soc8d soc8d_title soc8d_des soc n8d_within6d more_than_1_8d green_title green_category
duplicates drop
ta green_category, m

* Sorting by 6-digits SOCE and saving as a temporal database
sort soc
tempfile list_occ_total
save "`list_occ_total'", replace


/*==============================================================================================
	5 - Preparing Occupational Structure Database for the USA
==============================================================================================*/

* Loads 2018 national level data of "Occupational employment and wage statistics"
import excel using "${base_in_11}", first clear

* Renaming for lowercase
rename *, lower

* Generating 6-digits SOC code
destring occ_code, ignore("-") gen(soc)

* Preserving observations at the 6-digits level
* Note: Occupation total is 144,733,270 from the data first row. The total changes to 144,731,220 when preserving only occupations at the detailed level (6-digits). Around 2,000 workers are lost since some occupations do not have the detailed 6-digits level or by rounding. Since they share is small we proceed with ISCO codes.
keep if occ_group=="detailed"

* Preserving the only relevant variable: employment quantity by 6-digits SOC code (and the code description)
keep soc occ_title tot_emp 
label var tot_emp "US Estimated total employment rounded to the nearest 10 (excludes self-employed)"
label var occ_title "US Occupation title"

* Sorting and saving as a temporal database
sort soc
tempfile employ_struct_usa
save "`employ_struct_usa'", replace


/*==============================================================================================
	6 - Processing Database at 4-digits ISCO code
==============================================================================================*/

* Loads crosswalk database from ISCO to 6-digits SOC
import excel using "${base_in_12}", first clear

* Correcting misread ISCO codes
replace ISCO08Code ="3322" if ISCO08Code=="3322 "
replace ISCO08Code ="5169" if ISCO08Code=="5169 "
replace ISCO08Code ="7422" if ISCO08Code=="7422 "

* Generating 6-digits SOC codes
destring SOCCode, ignore("-") gen(soc)

* Preserving relevant variables and joining to a database with total occupations
keep ISCO08Code ISCO08TitleEN part SOCCode soc SOCTitle
sort soc
joinby soc using "`list_occ_total'"
* Note:  Since the crosswalk is available at the sub-group level and the SOC code never ends en zero, the 191020 SOC code does not have an associated ISCO code. It seems a unique 8-digits SOC code whose 6-digits version ends in zero (19-1020.01-Biologist) in the occupations list, but it should be ignored since Biologists are included in sub-groups 19-1021 to 19-1029, all of them associated to the same ISCO code (2131).

* Renaming variables and dropping string SOC
rename ISCO08Code isco
rename ISCO08TitleEN isco_title
rename SOCTitle soc_title
drop SOCCode

* Joining the USA employment structure database with the number of workers by 2018 SOC code
sort soc
merge soc using "`employ_struct_usa'"
ta _merge

* Note: 797 out of the 841 6-digits SOC codes in O*NET have employment in the USA and the remaining 44 have not (_merge==1). There are other 12 cases with employment in the USA (6-digits SOC) but that are not available in O*NET (_merge==2).

* 12 occupations with positive employment in the USA not available in O*NET:
	list soc if _merge==2
	* 6 of those 12 codes end in zero. These are 5-digits USA occupations. For these cases, the employment level at 5-digits is evenly distributed among the 6-digits SOC codes from O*NET.

	* 5-digits SOC codes
	sort soc
	tostring soc, gen(soc_str)
	gen soc5d = substr(soc_str,1,5)

	* Identifying occupations that are sub-groups of a 6-digits SOC code
	gen aux = substr(soc8d,-2,2) 
	gen subsoc = .
	replace subsoc = 0 if aux=="00"
	replace subsoc = 1 if aux!="00" & aux!=""
	label var subsoc "1 = Occupation is a subgroup within 6-digit SOC"
	drop aux

	* Evenly distribution of employment of the six 5-digits USA occupations among the 6-digits codes (_merge==2 and the code ends in 0 at the 6-digits level)
	sort soc
	egen suma_emp = sum(tot_emp), by(soc5d)
	foreach s of numlist 13102 15209 29201 39101 39701 47409 {
		count if soc5d=="`s'" & soc!=soc[_n-1] & _merge==1
		replace tot_emp=suma_emp/r(N) if soc5d=="`s'" & _merge==1
		}
	drop suma_emp
	* Note: With this change, occupations in O*NET without employment level reduce from 44 to 31.

	* The other 6 out of the 12 discrepancies at the 6-digits level do not match due small differences between the USA and O*NET definitions. Each case is treated separately below:
	
	* Occupations with employments level at the 6-digits USA classification missing in O*NET
	* br isco soc soc5d soc8d tot_emp _merge if soc5d=="21101" | soc5d=="25309" | soc5d=="51202" | soc5d=="51209" | soc5d=="53104" 
	* SOC 211018 in USA (Substance Abuse, Behavioral Disorder, and Mental Health Counselors) is evenly distributed between SOC 211011 (Substance Abuse and Behavioral Disorder Counselors) and SOC 211014 (Mental Health Counselors) from O*NET
	sum tot_emp if soc==211018
	replace tot_emp = r(mean)/2 if soc==211011 | soc==211014
	* SOCs 253097 and 253098 in USA (Teachers and Instructors, All Other, Except Substitute Teachers + Substitute Teachers) are assigned to SOC 253099 from O*NET (Teachers and Instructors, All Other)
	sum tot_emp if soc==253097 | soc==253098
	replace tot_emp = r(sum) if soc==253099
	* SOC 512028 in USA (Electrical, Electronic, and Electromechanical Assemblers, Except Coil Winders, Tapers, and Finishers) is evenly distributed between SOCs 512022 and 512023 from O*NET (Electrical and Electronic Equipment Assemblers + Electromechanical Equipment Assemblers)
	sum tot_emp if soc==512028
	replace tot_emp = r(mean)/2 if soc==512022 | soc==512023
	* SOC 512098 in USA (Assemblers and Fabricators, All Other, Including Team Assemblers) is evenly distributed between SOCs 512092 and 512099 from O*NET (Team Assemblers + Assemblers and Fabricators, All Other)
	sum tot_emp if soc==512098
	replace tot_emp = r(mean)/2 if soc==512092 | soc==512099 
	* SOC 531048 in USA (First-Line Supervisors of Transportation and Material Moving Workers, Except Aircraft Cargo Handling Supervisors) corresponds to SOC 531031 from O*NET (First-Line Supervisors of Transportation and Material-Moving Machine and Vehicle Operators)
	sum tot_emp if soc==531048
	replace tot_emp = r(mean) if soc==531031

* Dropping the 12 SOC available only in USA employment database since the information is now incorporated in O*NET
drop if _merge==2
drop _merge soc_str soc5d

* The remaining mismatched cases are considered as with zero employment (19 with ISCO 0 (military), 2 are SOCs 53 + 453011 and 453021)
replace tot_emp = 0 if tot_emp==.

* Evenly distribution of employment when a 6-digits SOC has 8-digits sub-categories
replace tot_emp = tot_emp/n8d_within6d
rename tot_emp tot_emp_soc8d

* Share of total employment in the ISCO code in the corresponding 8-digits SOC codes 
sort isco
egen tot_emp_isco = sum(tot_emp_soc8d), by(isco)
gen prop_emp_isco = tot_emp_soc8d/tot_emp_isco
label var prop_emp_isco "Proportion of employment within the ISCO corresponding to the soc"
drop tot_emp_isco

* General 8-digits SOC occupation category
gen occ_category = .
replace occ_category = 1 if green_category=="Green New & Emerging"
replace occ_category = 2 if green_category=="Green Enhanced Skills"
replace occ_category = 3 if green_category=="Green Increased Demand"
replace occ_category = 4 if green_category=="Green Rival"
replace occ_category = 5 if green_category=="Other Non-green"
label define occ_category 1 "Green New & Emerging" 2 "Green Enhanced Skills" 3 "Green Increased Demand" 4 "Green Rival" 5 "Other Non-green"
label values occ_category occ_category
label var occ_category "General occupational category (SOC)"

* Share of ISCO corresponding to each occupation category 
egen prop_new_emerging     = sum(prop_emp_isco) if occ_category == 1, by(isco) missing
egen prop_enhanced_skills  = sum(prop_emp_isco) if occ_category == 2, by(isco) missing
egen prop_increased_demand = sum(prop_emp_isco) if occ_category == 3, by(isco) missing
egen prop_rival            = sum(prop_emp_isco) if occ_category == 4, by(isco) missing
egen prop_other            = sum(prop_emp_isco) if occ_category == 5, by(isco) missing

* Probability that an isco is an occupation of a given category (the previous shares are used as probabilities and we put them here in the same row)
* The probability for a particular ISCO is given by the value (mean, min, and max, because it is unique) of the employment share computed above in the corresponding category.
egen prob_new_emerging_4d     = mean(prop_new_emerging)     , by(isco)
egen prob_enhanced_skills_4d  = mean(prop_enhanced_skills)  , by(isco)
egen prob_increased_demand_4d = mean(prop_increased_demand) , by(isco)
egen prob_rival_4d            = mean(prop_rival)            , by(isco)
egen prob_other_4d            = mean(prop_other)            , by(isco)

* Assigning probability zero to the remaining values.
foreach var of varlist prob_new_emerging prob_enhanced_skills prob_increased_demand prob_rival prob_other {
	replace `var'=0 if `var'==.
	}
label var prob_new_emerging_4d     "Probability of being a green new and emerging occupation for the 4d ISCO"
label var prob_enhanced_skills_4d  "Probability of being a green enhanced skills occupation for the 4d ISCO"
label var prob_increased_demand_4d "Probability of being a green increased demand occupation for the 4d ISCO"
label var prob_rival_4d            "Probability of being a green rival occupation for the 4d ISCO"
label var prob_other_4d            "Probability of being other non-green occupation for the 4d ISCO"
drop prop_new_emerging prop_enhanced_skills prop_increased_demand prop_rival prop_other

* Dropping ISCOs 211 and 315 for being 3-digits codes associated to a 6-digits SOC.
* Note: Dropping code 315 does not have effect since all sub-groups are non-green. Code 211 is associated to a "new and emerging" 6-digits SOC, which is inconsistent with the ISCO 211 sub-group classification into categories that are all non-green. In any case, we keep the 4-digits ISCO classification.
drop if isco=="211" | isco=="315"

* Dropping "Military" ISCO codes (ISCO 0)
drop if isco=="0110" | isco=="0210" | isco=="0310"

* Sorting and saving with only one ISCO  
sort isco
preserve
	keep isco isco_title prob*
	duplicates drop
	rename isco isco_4d
	save "${base_out_5}", replace
restore


/*==============================================================================================
	7 - Processing Database at 3-digits, 2-digits, and 1-digit ISCO level
==============================================================================================*/

* Dropping unnecessary variables
drop isco_title part

* Renaming isco as isco_4d
rename isco isco_4d

* Starting counter for the database number to be saved
loc b = 2

** Looping by the # of digits in the ISCO code
forvalues d=3(-1)1 {

	* Upper digit 
	local s = `d'+1
	local y = `d'+5

	* Dropping variables generated at an upper digit
	drop prop_emp_isco prob_new_emerging prob_enhanced_skills prob_increased_demand prob_rival prob_other

	* Generating ISCO at "d" digits 
	gen isco_`d'd=substr(isco_`s'd,1,`d')

	* Dropping ISCO at an upper level and any duplicates so that the "d" digits ISCO has a single 8-digits SOC associated.
	drop isco_`s'd 
	duplicates drop

	* Share of total employment by ISCO at "d" digits corresponding to its respective 8-digits SOC
	sort isco_`d'd
	egen tot_emp_isco_`d'd = sum(tot_emp_soc8d), by(isco_`d'd)
	gen prop_emp_isco = tot_emp_soc8d/tot_emp_isco_`d'd
	label var prop_emp_isco "Proportion of employment within the ISCO corresponding to the soc"
	drop tot_emp_isco_`d'd

	* Share of ISCO corresponding to each occupation category
	egen prop_new_emerging     = sum(prop_emp_isco) if occ_category == 1, by(isco_`d'd) missing
	egen prop_enhanced_skills  = sum(prop_emp_isco) if occ_category == 2, by(isco_`d'd) missing
	egen prop_increased_demand = sum(prop_emp_isco) if occ_category == 3, by(isco_`d'd) missing
	egen prop_rival            = sum(prop_emp_isco) if occ_category == 4, by(isco_`d'd) missing
	egen prop_other            = sum(prop_emp_isco) if occ_category == 5, by(isco_`d'd) missing

	* Probability that an isco is an occupation of a given category (the previous shares are used as probabilities and we put them here in the same row)
	* The probability for a particular ISCO is given by the value (mean, min, and max, because it is unique) of the employment share computed above in the corresponding category.
	egen prob_new_emerging_`d'd     = mean(prop_new_emerging)     , by(isco_`d'd)
	egen prob_enhanced_skills_`d'd  = mean(prop_enhanced_skills)  , by(isco_`d'd)
	egen prob_increased_demand_`d'd = mean(prop_increased_demand) , by(isco_`d'd)
	egen prob_rival_`d'd            = mean(prop_rival)            , by(isco_`d'd)
	egen prob_other_`d'd            = mean(prop_other)            , by(isco_`d'd)

	* Assigning probability zero to the remaining values.
	foreach var of varlist prob_new_emerging_`d'd prob_enhanced_skills_`d'd prob_increased_demand_`d'd prob_rival_`d'd prob_other_`d'd {
		replace `var'=0 if `var'==.
		}
	label var prob_new_emerging_`d'd     "Probability of being a green new and emerging occupation for the `d'd ISCO"
	label var prob_enhanced_skills_`d'd  "Probability of being a green enhanced skills occupation for the `d'd ISCO"
	label var prob_increased_demand_`d'd "Probability of being a green increased demand occupation for the `d'd ISCO"
	label var prob_rival_`d'd            "Probability of being a green rival occupation for the `d'd ISCO"
	label var prob_other_`d'd            "Probability of being other non-green occupation for the `d'd ISCO"
	drop prop_new_emerging prop_enhanced_skills prop_increased_demand prop_rival prop_other

	* Sorting and saving with only one ISCO at "d" digits
	sort isco_`d'd
	preserve
		keep isco_`d'd prob*
		duplicates drop
		save "${base_out_`y'}", replace
		loc ++b
	restore
	}

	
/*==============================================================================================
  - END
==============================================================================================*/