
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

PROCESS_ILOSTAT.DO

Description: Process employment database from ILOSTAT.

==============================================================================================*/


/*==============================================================================================
	1 - Employment Database at 2-digits level
==============================================================================================*/

* Loads ILOSTAT employment database by 2-digits occupation 
use "${base_in_13}", clear

* Generating 2-digits ISCO identifier
gen isco_2d = usubstr(classif1_label, 38, 2)
label var isco_2d "2 digits ISCO code"

* Dropping gender specific observations (we use total employment)
drop if sex_label!="Sex: Total"

* Total employment by country
gen emp_tot_ilo = obs_value if isco_2d=="To"
egen emp_tot_cnt = max(emp_tot_ilo ), by( ref_area_label time )
drop emp_tot_ilo
label var emp_tot_cnt "Total employment in the country-year"

* Dropping overall total employment and employment not classified in any ISCO
drop if isco_2d=="To" | isco_2d=="No"

* Generating ISCO classification Identifier (88 or 08)
gen class_isco = usubstr(classif1_label, 18, 2)
label var class_isco "ISCO classification (88 vs. 08)"

* Merging with 2-digits green occupations database
sort isco_2d
merge isco_2d using "${base_out_7}"
ta _merge

* Dropping employment in "Military" occupations (ISCO 0)
ta isco_2d if _merge==1, m
drop if _merge==1
drop _merge

* Generating green job probability as the sum of N&E, ES, and ID
gen prob_green_2d = prob_new_emerging + prob_enhanced_skills + prob_increased_demand
label var prob_green_2d "Probability of being a green occupation for the 2d ISCO"

* Generating non-green job probability as the sum of rival and other
gen prob_non_green_2d = prob_rival + prob_other
label var prob_non_green_2d "Probability of being a non-green occupation for the 2d ISCO"

* Year and Country variables
destring time, replace
rename time year
label var year "Year"
rename ref_area_label country
label var country "Country"

* Dropping observations with ISCO 88
keep if class_isco == "08"
drop class_isco

* Dropping an atypical observation in Maldivas 2014 (it only has a unique ISCO at 2-digits)
drop if country=="Maldives" & year==2014

* Dropping unnecessary variables
drop indicator_label sex_label classif1_label

* Rename employment variable
rename obs_value employment_2d
label var employment_2d "Employment by occupation - ISCO level 2 (thousands)"

* Sorting
order country year isco_2d employment_2d prob* 
sort country year isco_2d 

* World Regions 
preserve
	qui wbopendata, indicator(SP.POP.TOTL) year(2019) projection clear
	keep countrycode countryname region regionname
	ren countryname country

	* Countries names  - Not found equivalents for Cook Islands, Montserrat, Occupied Palestinian Territory
	qui replace country = "Côte d'Ivoire" 					if country == "Cote d'Ivoire"
	qui replace country = "Egypt" 							if country == "Egypt, Arab Rep"
	qui replace country = "Gambia" 							if country == "Gambia, The"
	qui replace country = "Iran, Islamic Republic of" 		if country == "Iran, Islamic Rep"
	qui replace country = "Kyrgyzstan"			 			if country == "Kyrgyz Republic"
	qui replace country = "Lao People's Democratic Republic" if country == "Lao PDR"
	qui replace country = "Micronesia, Federated States of" if country == "Micronesia, Fed Sts"
	qui replace country = "Slovakia"						if country == "Slovak Republic"
	qui replace country = "Turkey" 							if country == "Turkiye"

	sort region country
	order region regionname
	tempfile regions
	save `regions', replace
restore

merge m:1 country using `regions', keep(1 3) nogen

* Total employment by Country-Year
egen tot_emp = sum(employment_2d), by(country year) 


/*==============================================================================================
	2 - Graphs and Summary Stats
==============================================================================================*/

* Share of employment by country and type
local categories = "new_emerging enhanced_skills increased_demand rival other green non_green"
foreach cat of local categories {
	gen tot_emp_`cat' = prob_`cat'_2d * employment_2d
	egen `cat'_emp = sum(tot_emp_`cat'), by(country year) 
	gen prop_`cat' = `cat'_emp/tot_emp
}

* Labels
label var prop_new_emerging 	"Proportion of employment in green new and emerging occupations" 
label var prop_enhanced_skills 	"Proportion of employment in green enhanced skills occupations" 
label var prop_increased_demand "Proportion of employment in green increased demand occupations" 
label var prop_rival 			"Proportion of employment in green rival occupations" 
label var prop_other 			"Proportion of employment in other non-green occupations" 
label var prop_green 			"Proportion of employment in green occupations" 
label var prop_non_green 		"Proportion of employment in non-green occupations" 

* Preserving necessary variables at the Country-Year level
keep country year region regionname prop* emp_tot_cnt tot_emp
duplicates drop

* Saving processed database
sort country year
save "${base_out_9}", replace

* Identifying last available year by country
bysort country: egen max_year = max(year)

* Keep only last available year information
keep if year == max_year
drop max_year

* Change format to percentage
foreach var of varlist prop_new_emerging-prop_non_green {
	replace `var' = `var' * 100
}

* Paper summary stats
noi sum prop_green prop_enhanced_skills prop_increased_demand prop_new_emerging
noi bysort region: sum prop_green prop_enhanced_skills prop_increased_demand prop_new_emerging

* Figure 2 – Green occupations (all types) across the world
export excel country year prop_green using "${figure_2}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels) 

* Figure 3 – Green occupations (by types) across the world
export excel country year prop_new_emerging prop_enhanced_skills prop_increased_demand using "${figure_3}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels) 

* Figure A2 – Green occupations (all types) across the world
collapse prop_green prop_new_emerging prop_enhanced_skills prop_increased_demand, by(regionname)
drop if regionname == ""

* Labels
label var prop_new_emerging 	"Proportion of employment in green new and emerging occupations" 
label var prop_enhanced_skills 	"Proportion of employment in green enhanced skills occupations" 
label var prop_increased_demand "Proportion of employment in green increased demand occupations" 
label var prop_green 			"Proportion of employment in green occupations" 

export excel region prop_green prop_new_emerging prop_enhanced_skills prop_increased_demand using "${figure_a2}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels) 

/*==============================================================================================
  - END
==============================================================================================*/