
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

MERGES_ILO_SEDLAC.DO

Description: Merge the green share database from ILOSTAT with the green share of SEDLAC.

==============================================================================================*/


/*==============================================================================================
 	1 - Merging LAC 2-digits employment database with ILO database
==============================================================================================*/

* Abre base de datos de empleo por ocupación a 2 dígitos para LAC enviada por Hernán
use "${base_in_7}", clear

* Dropping employment at 1-digit, 2-digits, and 3-digits ISCO
tostring isco08_2d, gen(isco_2d)
drop if isco_2d=="1" | isco_2d=="2" | isco_2d=="3"

* Merging with 2-digits green occupations database
sort isco_2d
merge isco_2d using "${base_out_7}"
ta _merge
drop _merge

* Generating green job probability as the sum of N&E, ES, and ID
gen prob_green_2d = prob_new_emerging + prob_enhanced_skills + prob_increased_demand
label var prob_green_2d "Probability of being a green occupation for the 2d ISCO"

* Generating non_green job probability as the sum of rival and other
gen prob_non_green_2d = prob_rival + prob_other
label var prob_non_green_2d "Probability of being a non-green occupation for the 2d ISCO"

ren (pais ano) (country year)
replace country = upper(country)

* Formatting countries' names to match ILOSTAT database
replace country = "Argentina"			if country=="ARG"
replace country = "Bolivia"				if country=="BOL"
replace country = "Brazil"				if country=="BRA"
replace country = "Chile"				if country=="CHL"
replace country = "Colombia"			if country=="COL"
replace country = "Costa Rica"          if country=="CRI"
replace country = "Dominican Republic"  if country=="DOM"
replace country = "Ecuador"				if country=="ECU"
replace country = "Guatemala"			if country=="GTM"
replace country = "Honduras"			if country=="HND"
replace country = "Latin America"		if country=="LAC"
replace country = "Mexico"				if country=="MEX"
replace country = "Nicaragua"			if country=="NIC"
replace country = "Panama"				if country=="PAN"
replace country = "Peru"				if country=="PER"
replace country = "El Salvador"			if country=="SLV"
replace country = "Uruguay"				if country=="URY"

* Renomes employment variable
rename n employment_2d
label var employment_2d "Employment by occupation - ISCO level 2"

* Sorting
order country year isco_2d employment_2d prob* 
sort country year isco_2d 
drop isco08_2d

* Total employment by Country-Year
egen tot_emp = sum(employment_2d), by(country year) 

* Share of employment by country and type
local categories = "new_emerging enhanced_skills increased_demand rival other green non_green"
foreach cat of local categories {
	gen tot_emp_`cat' = prob_`cat'_2d * employment_2d
	egen `cat'_emp = sum(tot_emp_`cat'), by(country year) 
	gen prop_`cat' = `cat'_emp/tot_emp
	}
label var prop_new_emerging 	"Proportion of employment in green new and emerging occupations" 
label var prop_enhanced_skills 	"Proportion of employment in green enhanced skills occupations" 
label var prop_increased_demand "Proportion of employment in green increased demand occupations" 
label var prop_rival 			"Proportion of employment in green rival occupations" 
label var prop_other 			"Proportion of employment in other non-green occupations" 
label var prop_green 			"Proportion of employment in green occupations" 
label var prop_non_green 		"Proportion of employment in non-green occupations" 

* SEDLAC's total employment in thousands with the same variable name as in ILOSTAT
gen emp_tot_cnt = tot_emp/1000
label var emp_tot_cnt "Total employment in the country-year"

* Keeping necessary variables at the Country-Year level
keep country year prop* emp_tot_cnt
duplicates drop

* Generating ILOSTAT source identifying variable
gen ilo = 0
label var ilo "1 = Employment estimate from ILOSTAT"

* Sorting and appending ILOSTAT database
sort country year
append using "${base_out_9}"
sort  country year ilo
order country year ilo

* Assigning 1 to all variables obtained from ILOSTATS database 
replace ilo = 1 if ilo!=0

* Generating indicator variable for Latin America
gen lac = 0
replace lac = 1 if country=="Argentina" | country=="Bolivia" | country=="Brazil" | country=="Chile" | country=="Colombia" | country=="Costa Rica" | country=="Dominican Republic" | country=="Ecuador" | country=="Guatemala" | country=="Honduras" | country=="Mexico" | country=="Nicaragua" | country=="Panama" | country=="Peru" | country=="El Salvador" | country=="Uruguay" 
label var lac "LAC country"

* Comparing own estimates with ILO for LAC countries
ta country ilo if lac==1

* Using SEDLAC data in the cases where there is not available data from ILO (COL, CRI, NIC) and when SEDLAC's time series is longer than in ILO's (ARG, CHL, PAN, PER)
drop if (country=="Argentina" | country=="Chile" | country=="Panama" | country=="Peru") & ilo==1
drop if (country!="Argentina" & country!="Chile" & country!="Panama" & country!="Peru" & country!="Colombia" & country!="Costa Rica" & country!="Nicaragua") & ilo==0
ta country ilo if lac==1

* Dropping Latin America aggregate
drop if country == "Latin America"

* Sorting and saving the database					
sort country year				          
saveold "${base_out_10}", replace			  
		
/*==============================================================================================
  - END
==============================================================================================*/