
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

CROSS_COUNTRY_STATS.DO

Description: Cross-country statistics based on last available data in ILO/SEDLAC database & WDI data

==============================================================================================*/


/*==============================================================================================
 	1 - Joining Per Capita GDP and Working Age Population using WDI
==============================================================================================*/

* Loads WDI database containing Per Capita GDP
import excel using "${base_in_14}", clear first

* Dropping unnecessary variables
drop TimeCode GDPpercapitaPPPcurrentint Servicesvalueaddedperworker-T

* Renaming variables
rename CountryName country
rename CountryCode cnt
rename Time year
rename GDPpercapitaPPPconstant20 gdp_pc
rename LaborforcetotalSLTLFTOTL labor_force
rename PopulationtotalSPPOPTOTL pop
rename Populationages014totalSP pop014

* Replacing double missing as empty
foreach var of varlist gdp_pc labor_force pop pop014 {
	replace `var' = "" if `var' == ".."
	}

* Changing variables' format to numeric
destring, replace

* Generating working age population as individuals aged 15 or more, in thousands
gen wapop = (pop- pop014)/1000
label var wapop "Working age population (population aged 15+)"
drop pop pop014

* Dropping years with missing data in per capita GDP and labor force
drop if gdp_pc==. & labor_force==. 

* Homogenizing WDI country-names to match ILO
replace country="Cape Verde" 						if country=="Cabo Verde"
replace country="Curaçao" 							if country=="Curacao"
replace country="Czechia" 							if country=="Czech Republic"
replace country="Côte d'Ivoire" 					if country=="Cote d'Ivoire"
replace country="Egypt" 							if country=="Egypt, Arab Rep."
replace country="Gambia" 							if country=="Gambia, The"
replace country="Iran, Islamic Republic of" 		if country=="Iran, Islamic Rep."
replace country="Korea, Republic of" 				if country=="Korea, Rep."
replace country="Kyrgyzstan" 						if country=="Kyrgyz Republic"
replace country="Lao People's Democratic Republic" 	if country=="Lao PDR"
replace country="Micronesia, Federated States of" 	if country=="Micronesia, Fed. Sts."
replace country="Occupied Palestinian Territory" 	if country=="West Bank and Gaza"
replace country="Slovakia" 							if country=="Slovak Republic"
replace country="Viet Nam" 							if country=="Vietnam"

* Sorting and merging with ILOSTAT data
sort country year
merge country year using "${base_out_10}"
ta _merge

* Dropping surplus observations of per capita GDP (when using ILO data there is always matching PBI_PC except for the case below )
drop if _merge==1

* Dropping observations corresponding to Cook Islands and Montserrat since they are not present in WDI (3 obs.)
drop if country=="Cook Islands" | country=="Montserrat"
drop _merge

* Log of per capita GDP
gen lgdp_pc = log(gdp_pc)
label var lgdp_pc "log (GDP per capita, PPP (constant 2017 international $))"

* Share of green jobs adjusted by working age population
foreach var of varlist prop_new_emerging prop_enhanced_skills prop_increased_demand prop_green prop_non_green prop_rival prop_other {
	gen `var'_wa = (`var'*emp_tot_cnt)/wapop
	label var `var'_wa "`var' (as % of working age pop.)"
	}

* Sorting the database with the aggregate derived from WDI
sort country year
save "${base_out_11}", replace


/*==============================================================================================
 	2 - Scatter plots GJ vs. Per Capita GDP & GJ as a % of Working Age Population
==============================================================================================*/

* Figure 4 - Percentage of green occupations and GDP per capita (2017 PPP $), latest available data.
preserve
	drop if prop_enhanced_skills==.
	keep if country!=country[_n+1] 
	keep country cnt year prop_new_emerging prop_enhanced_skills prop_increased_demand prop_green lgdp_pc
	export excel using "${figure_4}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore

* Figure 15 - Green occupations as % of the working age population and as % of total employment, latest available data.
preserve
	drop if prop_enhanced_skills==. | prop_enhanced_skills_wa==.
	keep if country!=country[_n+1] 
	keep country year prop_green_wa prop_green
	order country year prop_green_wa prop_green
	export excel using "${figure_15}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore

* Table A1 - Share of green occupations, latest available data
preserve
	drop if prop_enhanced_skills==.
	keep if country!=country[_n+1] 
	keep country year prop_new_emerging prop_enhanced_skills prop_increased_demand prop_green 
	export excel using "${table_a1}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore


/*==============================================================================================
 	3 - Scatter plots GJ vs. Human Capital and Informality
==============================================================================================*/

* keep one observation per country and saving as a temporal database
drop if prop_enhanced_skills==.
keep if country!=country[_n+1] 
keep country cnt year prop_new_emerging prop_enhanced_skills prop_increased_demand prop_green
tempfile ilo				   
sort cnt		   
save "`ilo'"

* Loading informality data, sorting and saving as a temporal database
use "${base_in_15}", clear 
keep if sex_label=="Sex: Total"
gen informality = obs_value/100
keep ref_area_label time informality
rename ref_area_label country
rename time year_informality
destring year_informality, replace
keep if country!=country[_n+1] 
replace country="Guinea" if country=="Guinea-Bissau"
tempfile informality
sort country 
save "`informality'"

* Loading HCI 2020 database, homogenizing country names, and saving as a temporal database
import excel using "${base_in_16}", first clear

	** Initial cleaning
	rename E valor2010
	rename L valor2017
	rename M valor2018
	rename O valor2020
	drop F G H I J K N

	** Converts the database to long format
	reshape long valor, i(CountryName CountryCode IndicatorName IndicatorCode) j(year)

	** Variables to use
	gen indicador = ""
	replace indicador ="hci"  if IndicatorName=="Human Capital Index (HCI) (scale 0-1)"
	replace indicador ="lays" if IndicatorName=="Learning-Adjusted Years of School"
	replace indicador ="not_stunted" if IndicatorName=="Fraction of Children Under 5 Not Stunted"
	replace indicador ="child_survival" if IndicatorName=="Probability of Survival to Age 5"
	replace indicador ="adult_survival" if IndicatorName=="Survival Rate from Age 15-60"
	replace indicador ="hts" if IndicatorName=="Harmonized Test Scores"
	replace indicador ="eyrs" if IndicatorName=="Expected Years of School"

	** Final cleaning
	drop IndicatorName IndicatorCode
	drop if indicador==""

	** Transforms to wide
	reshape wide valor, i(CountryName CountryCode year) j(indicador) string

	** Rename variables
	local indicadores = "adult_survival child_survival hci lays not_stunted hts eyrs"
	foreach i of local indicadores {
		rename valor`i' `i'
		}
	rename CountryName country
	rename CountryCode cnt

	** Put labels on variables
	label var hci "Human Capital Index (HCI) (scale 0-1)"
	label var lays "Learning-Adjusted Years of School"
	label var not_stunted "Fraction of Children Under 5 Not Stunted"
	label var child_survival "Probability of Survival to Age 5"
	label var adult_survival "Survival Rate from Age 15-60"
	label var hts "Harmonized Test Scores"
	label var eyrs "Expected Years of School"

	** Subcomponents of the index
	gen survival = child_survival
	label var survival "Survival subcomponent of HCI"
	gen school   = exp(0.08*(eyrs*hts/625-14))
	label var school   "School subcomponent of HCI"
	gen health   = exp((0.65*(adult_survival-1)+0.35*(not_stunted-1))/2)
	* When there is no health data because not_stunted es missing, it obtains it by residual
	replace health = hci /(survival*school) if health==.
	label var health "Health subcomponent of HCI"
	* Check that the aggregatation of the components gives the HCI as result
	gen hci2 = survival*school*health
	compare hci hci2
	drop hci2

	** When there is no data of "not stunted rate", it obtains it as a residual
	replace not_stunted = ((2*ln(health)-0.65*(adult_survival-1))/0.35)+1 if not_stunted==.

	** Orders
	order country cnt year hci child_survival lays adult_survival not_stunted hts eyrs

	** Indicator of Latin American countries
	gen lac = 0
	local lac_countries = "ABW ARG ATG BHS BLZ BOL BRA BRB CHL COL CRI CUB CUW CYM DMA DOM ECU GRD GTM GUY HND HTI JAM KNA LCA MAF MEX NIC PAN PER PRI PRY SLV SUR SXM TCA TTO URY VCT VEN VGB VIR"
	foreach c of local lac_countries {
		replace lac = 1 if cnt=="`c'"
		}
	label var lac "1 = LAC country"

	** Indicator of Central American countries
	local ca_countries = "CRI DOM GTM HND NIC PAN SLV"
	gen ca = 0
	foreach c of local ca_countries {
		replace ca = 1 if cnt=="`c'"
		}
	label var ca "1 = Central America country"

	** Rest of LAC with hci in both 2010 and 2020
	gen aux = 1 if (year==2010 | year==2020) & hci!=.
	egen ndatos_puntas = sum(aux), by(country)
	gen rest_lac= 1 if lac==1 & ca!=1 & ndatos_puntas==2
	drop aux ndatos_puntas
	label var rest_lac "1= Rest of LAC with hci in both 2010 and 2020"

	** Keeps database with the last hci data (it ends up being 2020 for everyone)
	sort country year
	keep if hci!=. 
	keep if country!=country[_n+1]
	rename year year_hci
	sort cnt
	drop year_hci lac ca rest_lac
	replace country="Côte d'Ivoire" 					if country=="Cote d'Ivoire"
	replace country="Czechia" 							if country=="Czech Republic"
	replace country="Egypt" 							if country=="Egypt, Arab Rep."
	replace country="Gambia" 							if country=="Gambia, The"
	replace country="Iran, Islamic Republic of" 		if country=="Iran, Islamic Rep."
	replace country="Kyrgyzstan" 						if country=="Kyrgyz Republic"
	replace country="Lao People's Democratic Republic" 	if country=="Lao PDR"
	replace country="Micronesia, Federated States of" 	if country=="Micronesia, Fed. Sts."
	replace country="Occupied Palestinian Territory" 	if country=="West Bank and Gaza"
	replace country="Slovakia" 							if country=="Slovak Republic"
	tempfile hci
	sort country
	
* Saving temporal file 
save "`hci'"

* Merging ILO and HCI 2020 data
use "`ilo'", clear
sort country 
merge country using "`hci'"
ta _merge
drop if _merge==2
drop _merge

* Merging with ILO informality data
sort country 
merge country using "`informality'"
ta _merge
drop if _merge==2
drop _merge

* Figure A6 - Green occupations, human capital and informality
export excel country cnt prop_green hci using "${figure_a6_a}" if hci!=., sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

export excel country cnt prop_green informality using "${figure_a6_b}" if informality!=., sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

/*==============================================================================================
  - END
==============================================================================================*/