
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				09/14/2021
Last update: 		05/02/2024
================================================================================================

LAC_APPENDS.DO

Description: This dofile creates LAC databases using SEDLAC to be merged with emissions data and green jobs data.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - Setting for database
==============================================================================================*/

* Empty files
clear
forvalues i = 2010/2019 {
	save "${sedlac}\circa_`i'", emptyok replace
}

* Globals for each circa

gl countries_2019 "ARG2019 BOL2019 BRA2019 CHL2017 COL2019 CRI2019 DOM2019 ECU2019 GTM2014 HND2019 MEX2018 NIC2014 PAN2018 PER2019 SLV2019 URY2019"  

gl countries_2018 "ARG2018 BOL2018 BRA2018 CHL2017 COL2018 CRI2018 DOM2018 ECU2018 GTM2014 HND2018 MEX2018 NIC2014 PAN2018 PER2018 SLV2018 URY2018" 

gl countries_2017 "ARG2017 BOL2017 BRA2017 CHL2017 COL2017 CRI2017 DOM2017 ECU2017 GTM2014 HND2017 MEX2018 NIC2014 PAN2018 PER2017 SLV2017 URY2017" 

gl countries_2016 "ARG2016 BOL2016 BRA2016 CHL2017 COL2016 CRI2016 DOM2017 ECU2016 GTM2014 HND2016 MEX2016 NIC2014 PAN2016 PER2016 SLV2016 URY2016" 

gl countries_2015 "ARG2016 BOL2015 BRA2015 CHL2015 COL2015 CRI2015 DOM2017 ECU2015 GTM2014 HND2015 MEX2016 NIC2014 PAN2016 PER2016 SLV2015 URY2015" 

gl countries_2014 "ARG2014 BOL2014 BRA2014 CHL2015 COL2014 CRI2014 DOM2017 ECU2014 GTM2014 HND2015 MEX2014 NIC2014 PAN2014 PER2016 SLV2014 URY2014"  

gl countries_2013 "ARG2013 BOL2013 BRA2013 CHL2013 COL2013 CRI2013 DOM2017 ECU2013 GTM2014 HND2015 MEX2014 NIC2014 PAN2013 PER2016 SLV2013 URY2013" 

gl countries_2012 "ARG2012 BOL2012 BRA2012 CHL2013 COL2012 CRI2012 DOM2017 ECU2013 GTM2014 HND2015 MEX2012 NIC2014 PAN2012 PER2016 SLV2013 URY2012" 

gl countries_2011 "ARG2011 BOL2012 BRA2012 CHL2011 COL2011 CRI2012 DOM2017 ECU2013 GTM2014 HND2015 MEX2012 NIC2014 PAN2011 PER2016 SLV2013 URY2011" 

gl countries_2010 "ARG2010 BOL2012 BRA2012 CHL2011 COL2011 CRI2012 DOM2017 ECU2013 GTM2014 HND2015 MEX2012 NIC2014 PAN2011 PER2016 SLV2013 URY2011" 


/*==============================================================================================
	1 - Data construction
==============================================================================================*/

forvalues circa = 2010/2019 {
	
	di in red "Circa `circa'"
	
	foreach country of global countries_`circa' {
    
		loc NOM = substr("`country'",1,3)  // country ISO
		loc year = substr("`country'",4,4) // year
		
		di in red "`NOM' - `year'"
		
		* Load the data
		if "`NOM'" == "DOM" {
			*cap datalib, country("`NOM'") year(`year') period(q03) mod(all) clear 
			qui dlw, country("`NOM'") year(`year') type(sedlac) period(q03) mod(all) clear
		}
			
		else if "`NOM'" == "BRA" {
			*cap datalib, country("`NOM'") year(`year') survey(pnadc) period(e1) mod(all) clear
			qui dlw, country("`NOM'") year(`year') type(sedlac) survey(pnadc) period(e1) mod(pov lab edu) clear
		}
		
		else if inlist("`NOM'","CHL","COL") {
			*cap datalib, country("`NOM'") year(`year') mod(all) clear
			qui dlw, country("`NOM'") year(`year') type(sedlac) mod(pov lab edu) clear
		}
		
		else if ("`NOM'"=="BOL" & `year'==2016) {
			*cap datalib, country("`NOM'") year(`year') survey(eh) mod(all) clear
			qui dlw, country("`NOM'") year(`year') type(sedlac) survey(eh) mod(all) clear
		}
		
		*else cap datalib, country("`NOM'") year(`year') mod(all) clear 
		else qui dlw, country("`NOM'") year(`year') type(sedlac) mod(all) clear
		
		* Keep only households used for poverty measurement
		qui keep if cohh==1 & ipcf!=.
		
		* Hourly labor income
		cap gen 	ilaho = ila / (hstrt * 4.3)
		qui replace ilaho = .	if  ilaho==0
		
		* Hourly labor income PPP 2011
		qui gen ilaho_ppp11 = ((ilaho * ipc11_sedlac) / ipc_sedlac) / (ppp11 * conversion)
		
		* Total labor income PPP 2011
		cap qui gen ila_ppp11 = ((ila * ipc11_sedlac) / ipc_sedlac) / (ppp11 * conversion)
		
		* Per capita family income
		cap qui gen ipcf_ppp11 = ((ipcf * ipc11_sedlac) / ipc_sedlac) / (ppp11 * conversion)
		
		* Destring ISCO codes
		qui destring isco*, replace
		
		* Keep necessary variables
		keep pondera hombre urbano nivel cohh ipcf_ppp11 isco08* sector1d sector ocupado edad empresa djubila dsegsale relab daguinaldo ila_ppp11 ilaho_ppp11 
		gen country = "`NOM'"
		gen year = `year'
		gen circa = `circa'
		
		* when isco08_2d has type mismatch
		cap destring isco08_2d, replace

		* Append country data
		qui append using "${sedlac}\circa_`circa'"
		order country year circa
		qui save "${sedlac}\circa_`circa'", replace
	
	}
}

/*==============================================================================================
  - END
==============================================================================================*/