
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				11/15/2021
Last update: 		05/02/2024
================================================================================================

GREEN_JOBS_CIRCA_2019.DO

Description: This dofile calculates estimates of green jobs for LAC region and by country, using circa 2019.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - Database Structure
==============================================================================================*/

clear all
tempname circa2019
tempfile aux
postfile `circa2019' str30(Country Year Aggregate Est Prob) using `aux', replace


/*==============================================================================================
	2 - Workers per sector and green job classification
==============================================================================================*/

* Load circa 2019
use "$sedlac\circa_2019.dta", clear
	
* Rounding weight
qui replace pondera = round(pondera)
		
* REMINDER: Always filter for coherent households.
qui cap keep if cohh==1 & ipcf_ppp11!=.
qui cap keep if ipcf_ppp11!=. // For those without cohh

* Demographics
cap drop mujer 
cap drop less_pri
cap drop prim
cap drop sec
cap drop ter
gen mujer = !hombre
gen rural = !urbano
gen less_pri = inlist(nivel,0,1)
gen prim = inlist(nivel,2,3)
gen sec = inlist(nivel,4,5)
gen ter = inlist(nivel,6)

* Income quintile 
gen quintile = .
levelsof country, local(countries)
foreach country of local countries {
	xtile quintile_`country' = ipcf [fw=pondera] if country == "`country'", n(5)
	replace quintile = quintile_`country' if country == "`country'"
	cap drop quintile_`country'
}
qui tab quintile, gen (quintile_)
drop quintile

* Informality
cap drop informal
cap drop formal
qui gen informal = .
qui gen formal = .
		
** BOL, BRA, CHL, COL, CRI, DOM, ECU, HND, SLV, PAN, PRY, PER, URY, NIC, GTM - Workers who do NOT receive a pension
qui replace informal= djubila == 0 if djubila!= . & inlist(country,"BOL","BRA","CHL","COL","CRI","DOM","ECU")
qui replace formal 	= djubila == 1 if djubila!= . & inlist(country,"BOL","BRA","CHL","COL","CRI","DOM","ECU")
qui replace informal= djubila == 0 if djubila!= . & inlist(country,"HND","SLV","PAN","PRY","PER","URY","NIC","GTM")
qui replace formal 	= djubila == 1 if djubila!= . & inlist(country,"HND","SLV","PAN","PRY","PER","URY","NIC","GTM")
	
** MEX - Workers who do NOT receive health insurance benefits
qui replace informal 	= dsegsale == 0 if dsegsale != . & country == "MEX"
qui replace formal 		= dsegsale == 1 if dsegsale != . & country == "MEX"
	
** ARG, HTI - Workers who do NOT receive a pension. For self-employed: workers who have NOT completed tertiary education
qui replace informal 	= djubila == 0 	if djubila != . & inlist(country,"ARG","HTI")
qui replace informal	= 1 			if relab == 3 	& inlist(country,"ARG","HTI") & nivel != 6 
qui replace formal 		= djubila == 1 	if djubila != . & inlist(country,"ARG","HTI")
qui replace formal 		= 1 			if relab == 3 	& inlist(country,"ARG","HTI") & nivel == 6 
		
* Firm size
qui gen small  = empresa == 2 if empresa != .
qui gen large  = empresa == 1 if empresa != .
qui gen public = empresa == 3 if empresa != .
		
* Economic sector (according to GHG emissions). In some cases sector1d is missing, then create missing variables.
qui count if sector1d != .
if r(N) != 0 { 
	gen cross_sector1  = (inrange(sector1d,1,2))	// Agriculture, hunting, forestry and fishing
	gen cross_sector2  = sector1d == 3				// Mining and quarrying
	gen cross_sector3  = inlist(sector1d,4,6) 		// Manufacturing, Construction & Industrial processes
	gen cross_sector4  = sector1d == 5				// Electricity, gas and water supply
	gen cross_sector5  = sector1d == 7				// Wholesale and retail trade
	gen cross_sector6  = sector1d == 9				// Transport, storage and communications
	gen cross_sector7  = sector1d == 8				// Hotels and restaurants
	gen cross_sector8  = sector1d == 10				// Financial intermediation
	gen cross_sector9  = sector1d == 11				// Real estate, renting and business activities
	gen cross_sector10 = sector1d == 12				// Public administration and defence
	gen cross_sector11 = sector1d == 13				// Education
	gen cross_sector12 = sector1d == 14				// Health and social work
	gen cross_sector13 = sector1d == 15				// Other community, social and personal service activities
	gen cross_sector14 = sector1d == 16				// Activities of private households as employers
}
else { // Some countries don't have sector defined (BOL 2000)
	forvalues s = 1/14 {
		gen cross_sector`s' = .
	}
}
		
/* Clean/Dirty sectors classification
sector 1 pollutant
sector 2 pollutant, green for CRI for years 2015/2018
sector 3 pollutant
sector 4 pollutant
sector 5 green
sector 6 pollutant
sector 7 green
sector 8 pollutant, green for ARG 2006, 2008/2014, 2017/2018 and CRI 2012
sector 9 green, pollutant for ARG 2006, 2008/2014, 2017/2018 and CRI 2012, 2015/2018
sector 10 green
sector 11 green
sector 12 green
sector 13 pollutant
sector 14 green
*/
		
egen pollutant_sector = rowtotal(cross_sector1-cross_sector4 cross_sector6 cross_sector8 cross_sector13)
egen green_sector = rowtotal(cross_sector5 cross_sector7 cross_sector9-cross_sector12 cross_sector14)
		
* Merge with green jobs probabilities
ren isco08_2d isco_2d
tostring isco_2d, replace force
merge m:1 isco_2d using "${base_out_7}", keep(1 3) keepusing(prob_new_emerging_2d prob_enhanced_skills_2d prob_increased_demand_2d) nogenerate
		
* Green jobs classification
ren prob_* *
qui egen green_job = rowtotal(new_emerging_2d enhanced_skills_2d increased_dem), missing // Green Jobs
qui gen non_green_job 	= 1 				- green_job
qui gen g_green_job		= green_sector		* green_job
qui gen n_green_job 	= pollutant 		* green_job
qui gen g_non_green_job = green_sector 		* non_green_job
qui gen n_non_green_job = pollutant_sector 	* non_green_job

* Shares by gender
preserve 

	* Collapse the database at the isco level
	collapse hombre mujer g_green_job n_green_job g_non_green_job n_non_green_job [iw=pondera] if ocupado==1 & inrange(edad,15,64), by(isco_2d)
	drop if isco_2d == "."
	
	* Creating gender shares
	for any g_green_job n_green_job g_non_green_job n_non_green_job: gen X_male = X * hombre
	for any g_green_job n_green_job g_non_green_job n_non_green_job: gen X_female = X * mujer
	
	* Organizing the database
	destring isco_2d, replace
	sort isco_2d
	keep isco_2d *_male *_female
	
	* Putting in %
	for any g_green_job n_green_job g_non_green_job n_non_green_job: replace X_male = X_male * 100
	for any g_green_job n_green_job g_non_green_job n_non_green_job: replace X_female = X_female * 100

	* Table A7.a  - Occupations with highest shares by Green Job vs. Green Sector - Females
	export excel isco_2d *_female using "${table_a7_a}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

	* Table A7.b  - Occupations with highest shares by Green Job vs. Green Sector - Females
	export excel isco_2d *_male using "${table_a7_b}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore


* Employment by sector and green jobs classification
foreach v of varlist non_green_job green_job new_emerging_2d enhanced_skills_2d increased_demand_2d g_green_job g_non_green_job n_green_job n_non_green_job {
	
	di in red "`v'"
	
	* Total Workers
	qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64)
	loc p_`v'=r(mean)
	post `circa2019' ("LAC") ("2019") ("Total") ("`v'") ("`p_`v''")
	
	* Gender
	foreach v2 of varlist hombre mujer {
		qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
	* Rural / Urban
	foreach v2 of varlist urban rural {
	    qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
	* Education
	foreach v2 of varlist less_pri prim sec ter {
	    qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
	* Income
	foreach v2 of varlist quintile_1 quintile_2 quintile_3 quintile_4 quintile_5 {
	    qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
	* Informality
	foreach v2 of varlist formal informal {
	    qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
	* Firm size
	foreach v2 of varlist small large public {
	    qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
	* Country-level
	local countries ARG BOL BRA CHL COL CRI DOM ECU GTM HND MEX NIC PAN PER SLV URY
	foreach country of local countries {
	    
		qui sum year if country == "`country'"
		loc year=r(mean)
		
		* Total Workers
		qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64) & country == "`country'"
		loc p_`v'=r(mean)
		post `circa2019' ("`country'") ("`year'") ("Total") ("`v'") ("`p_`v''")
		
		* Gender
		foreach v2 of varlist hombre mujer {
			qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64) & country == "`country'"
			loc p_`v'=r(mean)
			post `circa2019' ("`country'") ("`year'") ("`v2'") ("`v'") ("`p_`v''")
		}
				
	}
}

* Compile results
postclose `circa2019'
use `aux', clear
destring, replace

* Organizing database
replace Prob = Prob * 100
reshape wide Prob, i(Country Year Aggregate) j(Est) string
ren Prob* *
ren g_* *_g
ren n_* *_n


/*==============================================================================================
	3 - Figures
==============================================================================================*/

* Figure 5 – Green occupations and green sectors in LAC
preserve

	* Keep only necessary observation and order the database
	keep if Aggregate == "Total"
	keep Country Year green_job_g green_job_n non_green_job_g non_green_job_n
	order Country Year green_* non_green_*

	* Labels and categories
	la var Country 			"Country"
	la var Year 			"Year"
	la var green_job_g 		"Green Occ. in Green Sectors"
	la var green_job_n 		"Green Occ. in Non-green Sectors"
	la var non_green_job_g 	"Non-green Occ. in Green Sectors"
	la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

	* Save results
	compress
	gsort -non_green_job_n
	export excel using "${figure_5}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

	restore

* Figure 9 – Green and non-green occupations and sectors vs. job holder gender, education, and rural/urban residency in LAC, 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"hombre","mujer","less_pri","prim","sec","ter","urbano","rural")
	keep if Country == "LAC"
	keep Aggregate green_job_g green_job_n non_green_job_g non_green_job_n

	* Labels and categories
	la var green_job_g 		"Green Occ. in Green Sectors"
	la var green_job_n 		"Green Occ. in Non-green Sectors"
	la var non_green_job_g 	"Non-green Occ. in Green Sectors"
	la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

	gen 	Category = "Gender" 	if inlist(Aggregate,"hombre","mujer")
	replace Category = "Education" 	if inlist(Aggregate,"less_pri","prim","sec","ter")
	replace Category = "Area" 		if inlist(Aggregate,"urbano","rural")

	replace Aggregate = "Male" 				if Aggregate == "hombre"
	replace Aggregate = "Female" 			if Aggregate == "mujer"
	replace Aggregate = "Less than Primary" if Aggregate == "less_pri"
	replace Aggregate = "Primary" 			if Aggregate == "prim"
	replace Aggregate = "Secondary" 		if Aggregate == "sec"
	replace Aggregate = "Tertiary" 			if Aggregate == "ter"
	replace Aggregate = "Urban" 			if Aggregate == "urbano"
	replace Aggregate = "Rural" 			if Aggregate == "rural"

	* Save results
	compress
	order Category Aggregate green_* non_green_*
	sort Category Aggregate
	export excel using "${figure_9}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

* Figure 10 – Gender Gaps in green occupations, LAC countries 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"hombre","mujer")
	keep Country Aggregate new_emerging_2d enhanced_skills_2d increased_demand_2d

	* Reshape gender 
	reshape wide enhanced_skills_2d increased_demand_2d new_emerging_2d, i(Country) j(Aggregate) string
	for any enhanced_skills_2d increased_demand_2d new_emerging_2d: gen gap_X = Xhombre - Xmujer
	keep Country gap*

	* Labels and categories
	la var gap_new_emerging_2d 		"New Emerging"
	la var gap_enhanced_skills_2d 	"Enhanced Skills"
	la var gap_increased_demand_2d 	"Increased Demand"

	* Save results
	compress
	order Country gap_new_emerging_2d gap_enhanced_skills_2d gap_increased_demand_2d
	sort gap_enhanced_skills_2d
	export excel using "${figure_10}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

* Figure 11 – Green occupations by education level, LAC 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"less_pri","prim","sec","ter")
	keep Aggregate new_emerging_2d enhanced_skills_2d increased_demand_2d

	* Labels and categories
	la var new_emerging_2d 		"New Emerging"
	la var enhanced_skills_2d 	"Enhanced Skills"
	la var increased_demand_2d 	"Increased Demand"

	replace Aggregate = "Less than Primary" if Aggregate == "less_pri"
	replace Aggregate = "Primary" 			if Aggregate == "prim"
	replace Aggregate = "Secondary" 		if Aggregate == "sec"
	replace Aggregate = "Tertiary" 			if Aggregate == "ter"

	* Save results
	compress
	order Aggregate new_emerging_2d enhanced_skills_2d increased_demand_2d
	sort Aggregate
	export excel using "${figure_11}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

* Figure 12 – Green and non-green occupations and sectors vs. informality and firm size in LAC, 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"formal","informal","small","large","public")
	keep Aggregate green_job_g green_job_n non_green_job_g non_green_job_n

	* Labels and categories
	la var green_job_g 		"Green Occ. in Green Sectors"
	la var green_job_n 		"Green Occ. in Non-green Sectors"
	la var non_green_job_g 	"Non-green Occ. in Green Sectors"
	la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

	gen 	Category = "Informality" 	if inlist(Aggregate,"formal","informal")
	replace Category = "Firm Size" 		if inlist(Aggregate,"small","large","public")

	replace Aggregate = "Formal" 	if Aggregate == "formal"
	replace Aggregate = "Informal" 	if Aggregate == "informal"
	replace Aggregate = "Small" 	if Aggregate == "small"
	replace Aggregate = "Large" 	if Aggregate == "large"
	replace Aggregate = "Public" 	if Aggregate == "public"

	* Save results
	compress
	order Category Aggregate green_* non_green_*
	sort Category Aggregate
	export excel using "${figure_12}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

* Figure 13 – Green and non-green occupations by household income quintile, LAC 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"quintile_1","quintile_2","quintile_3","quintile_4","quintile_5")
	keep Aggregate new_emerging_2d enhanced_skills_2d increased_demand_2d non_green_job

	* Labels and categories
	la var new_emerging_2d 		"New Emerging"
	la var enhanced_skills_2d 	"Enhanced Skills"
	la var increased_demand_2d 	"Increased Demand"
	la var non_green_job	 	"Non-green Jobs"

	replace Aggregate = "Quintile 1" if Aggregate == "quintile_1"
	replace Aggregate = "Quintile 2" if Aggregate == "quintile_2"
	replace Aggregate = "Quintile 3" if Aggregate == "quintile_3"
	replace Aggregate = "Quintile 4" if Aggregate == "quintile_4"
	replace Aggregate = "Quintile 5" if Aggregate == "quintile_5"

	* Save results
	compress
	order Aggregate new_emerging_2d enhanced_skills_2d increased_demand_2d non_green_job
	sort Aggregate
	export excel using "${figure_13}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

* Figure 14 – Green and non-green occupations and sectors vs. household income quintiles, LAC 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"quintile_1","quintile_2","quintile_3","quintile_4","quintile_5")
	keep Aggregate green_job_g green_job_n non_green_job_g non_green_job_n

	* Labels and categories
	la var green_job_g 		"Green Occ. in Green Sectors"
	la var green_job_n 		"Green Occ. in Non-green Sectors"
	la var non_green_job_g 	"Non-green Occ. in Green Sectors"
	la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

	replace Aggregate = "Quintile 1" if Aggregate == "quintile_1"
	replace Aggregate = "Quintile 2" if Aggregate == "quintile_2"
	replace Aggregate = "Quintile 3" if Aggregate == "quintile_3"
	replace Aggregate = "Quintile 4" if Aggregate == "quintile_4"
	replace Aggregate = "Quintile 5" if Aggregate == "quintile_5"

	* Save results
	compress
	order Aggregate green_* non_green_*
	sort Aggregate
	export excel using "${figure_14}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

/*==============================================================================================
  - END
==============================================================================================*/