
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				04/19/2021
Last update: 		05/02/2024
================================================================================================

NON_GREEN_JOBS_AGRICULTURE.DO

Description: This dofile estimates the share of non-green jobs in agricultural employment using circa 2019.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - Database Structure
==============================================================================================*/

clear all
tempname circa2019
tempfile aux
postfile `circa2019' str30(Country Year Aggregate Category Prob) using `aux', replace


/*==============================================================================================
	2 - Workers per sector and green job classification
==============================================================================================*/

* Load circa 2019
use "$sedlac\circa_2019.dta", clear
	
* Rounding weight
qui replace pondera = round(pondera)
		
* REMINDER: Always filter for coherent households.
qui cap keep if cohh==1 & ipcf_ppp11!=.
qui cap keep if ipcf_ppp11!=. // For those without cohh

* Employment in agriculture
gen agro = inrange(sector1d,1,2)
				
* Merge with green jobs probabilities
ren isco08_2d isco_2d
tostring isco_2d, replace force
merge m:1 isco_2d using "${base_out_7}", keep(1 3) keepusing(prob_new_emerging_2d prob_enhanced_skills_2d prob_increased_demand_2d) nogenerate
		
* Green jobs classification
ren prob_* *
qui egen green_job = rowtotal(new_emerging_2d enhanced_skills_2d increased_dem), missing // Green Jobs
qui gen non_green_job = 1 - green_job

* Agricultural Workers LAC
qui sum agro [w=pondera] if ocupado==1 & inrange(edad,15,64)
loc p_agro=r(mean)
post `circa2019' ("LAC") ("2019") ("LAC") ("Agriculture") ("`p_agro'")

* Non-green Workers in Agriculture LAC
qui sum non_green_job [w=pondera] if ocupado==1 & inrange(edad,15,64) & agro == 1
loc p_non_green_job=r(mean)
post `circa2019' ("LAC") ("2019")  ("Agriculture") ("Non_green") ("`p_non_green_job'")

* Green and Non-green Workers in Agriculture by ISCO
levelsof isco_2d, local (isco)
foreach i of local isco {
	
	* Green 
	qui sum green_job [w=pondera] if ocupado==1 & inrange(edad,15,64) & agro == 1 & isco_2d == "`i'"
	loc p_green_job=r(mean)
	post `circa2019' ("LAC") ("2019") ("Green") ("`i'") ("`p_green_job'")
	
	* Non-green 
	qui sum non_green_job [w=pondera] if ocupado==1 & inrange(edad,15,64) & agro == 1 & isco_2d == "`i'"
	loc p_non_green_job=r(mean)
	post `circa2019' ("LAC") ("2019") ("Non_green") ("`i'") ("`p_non_green_job'")
}
	
* Country-level
local countries ARG BOL BRA CHL COL CRI DOM ECU GTM HND MEX NIC PAN PER SLV URY
foreach country of local countries {
	    
	qui sum year if country == "`country'"
	loc year=r(mean)
	
	* Agricultural Workers
	qui sum agro [w=pondera] if ocupado==1 & inrange(edad,15,64) & country == "`country'"
	loc p_agro=r(mean)
	post `circa2019' ("`country'") ("`year'") ("LAC") ("Agriculture") ("`p_agro'")
			
	* Non-green Workers in Agriculture
	qui sum non_green_job [w=pondera] if ocupado==1 & inrange(edad,15,64) & country == "`country'" & agro == 1
	loc p_non_green_job=r(mean)
	post `circa2019' ("`country'") ("`year'")  ("Agriculture") ("Non_green") ("`p_non_green_job'")
			
			
}

* Compile results
postclose `circa2019'
use `aux', clear
destring, replace

* Converting to %
replace Prob = Prob * 100


/*==============================================================================================
	3 - Figure 6 – Share of non-green occupations in the agriculture sector in LAC countries
==============================================================================================*/

preserve 

	* Keep only totals
	keep if inlist(Category,"Agriculture","Non_green")
	drop Aggregate

	* Organizing database
	reshape wide Prob, i(Country Year) j(Category) string
	ren Prob* *

	* Labels and categories
	la var Country 			"Country"
	la var Year 			"Year"
	la var Agriculture 		"Employment in Agriculture (share)"
	la var Non_green	 	"Non-green Occupations in agriculture (share)"

	* Save results
	compress
	sort Agriculture
	export excel using "${figure_6}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore


/*==============================================================================================
	4 - Table A8 – Share of green and non-green occupations in the agriculture by ISCO
==============================================================================================*/

* Keep only isco values
drop if inlist(Category,"Agriculture","Non_green")
drop if Prob == .

* Organizing database
reshape wide Prob, i(Country Year Category) j(Aggregate) string
ren Prob* *
drop Country Year

* Labels and categories
la var Category		"2-digits ISCO"
la var Green		"Green employment in Agriculture (share)"
la var Non_green	"Non-green employment in agriculture (share)"

* Save results
compress
sort Category
export excel using "${table_a8}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

/*==============================================================================================
  - END
==============================================================================================*/