
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				09/08/2021
Last update: 		05/02/2024
================================================================================================

GREEN_JOBS_LAC_SERIES.DO

Description: This dofile creates the green job series of LAC region.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - Database Structure
==============================================================================================*/

tempname margins
tempfile aux
postfile `margins' str30(Country Year Est Prob) using `aux', replace


/*==============================================================================================
	2 - Workers per sector and green job classification
==============================================================================================*/

foreach year of numlist 2010/2019 { // Open loop year
		
	* Loading the data
	
	di in red "`year'"
	use "$sedlac\circa_`year'.dta", clear
	
	* Rounding weight
	qui replace pondera = round(pondera)
		
	* REMINDER: Always filter for coherent households.
	qui cap keep if cohh==1 & ipcf_ppp11!=.
	qui cap keep if ipcf_ppp11!=. // For those without cohh
	
		
	* Economic sector (according to GHG emissions). In some cases sector1d is missing, then create missing variables.
	qui count if sector1d != .
	if r(N) != 0 { 
		qui gen cross_sector1 = (inrange(sector1d,1,2))	// Agriculture, hunting, forestry and fishing
		qui gen cross_sector2 = sector1d == 3			// Mining and quarrying
		qui gen cross_sector3 = inlist(sector1d,4,6) 	// Manufacturing, Construction & Industrial processes
		qui gen cross_sector4 = sector1d == 5			// Electricity, gas and water supply
		qui gen cross_sector5 = sector1d == 7			// Wholesale and retail trade
		qui gen cross_sector6 = sector1d == 9			// Transport, storage and communications
		qui gen cross_sector7 = sector1d == 8			// Hotels and restaurants
		qui gen cross_sector8 = sector1d == 10			// Financial intermediation
		qui gen cross_sector9 = sector1d == 11			// Real estate, renting and business activities
		qui gen cross_sector10 = sector1d == 12			// Public administration and defence
		qui gen cross_sector11 = sector1d == 13			// Education
		qui gen cross_sector12 = sector1d == 14			// Health and social work
		qui gen cross_sector13 = sector1d == 15			// Other community, social and personal service activities
		qui gen cross_sector14 = sector1d == 16			// Activities of private households as employers
	}
	else { // Some countries don't have sector defined (BOL 2000)
		forvalues s = 1/14 {
			qui gen cross_sector`s' = .
		}
	}
		
	/* Clean/Dirty sectors classification
	sector 1 pollutant
	sector 2 pollutant, green for CRI for years 2015/2018
	sector 3 pollutant
	sector 4 pollutant
	sector 5 green
	sector 6 pollutant
	sector 7 green
	sector 8 pollutant, green for ARG 2006, 2008/2014, 2017/2018 and CRI 2012
	sector 9 green, pollutant for ARG 2006, 2008/2014, 2017/2018 and CRI 2012, 2015/2018
	sector 10 green
	sector 11 green
	sector 12 green
	sector 13 pollutant
	sector 14 green
	*/
		
	qui egen pollutant_sector = rowtotal(cross_sector1-cross_sector4 cross_sector6 cross_sector8 cross_sector13)
	qui egen green_sector = rowtotal(cross_sector5 cross_sector7 cross_sector9-cross_sector12 cross_sector14)
		
	if country == "CRI" & inrange(year,2015,2018)		& cross_sector2 == 1 qui replace pollutant_sector == 0 
	if country == "CRI" & (year == 2012) 				& cross_sector8 == 1 qui replace pollutant_sector == 0 
	if country == "CRI" & !inlist(year,2013,2014) 		& cross_sector9 == 1 qui replace pollutant_sector == 1 
	if country == "ARG" & !inlist(year,2005,2007,2016) 	& cross_sector8 == 1 qui replace pollutant_sector == 0 
	if country == "ARG" & !inlist(year,2005,2007,2016) 	& cross_sector9 == 1 qui replace pollutant_sector == 1 
		
	* Merge with green jobs probabilities
	ren isco08_2d isco_2d
	qui tostring isco_2d, replace force
	qui merge m:1 isco_2d using "${base_out_7}", keep(1 3) keepusing(prob_new_emerging_2d prob_enhanced_skills_2d prob_increased_demand_2d) nogenerate
		
	* Green jobs classification
	ren prob_* *
	qui egen green_job = rowtotal(new_emerging_2d enhanced_skills_2d increased_dem), missing // Green Jobs
	qui gen non_green_job 		= 1 				- green_job
	qui gen g_green_job 		= green_sector 		* green_job
	qui gen n_green_job 		= pollutant 		* green_job
	qui gen g_non_green_job 	= green_sector 		* non_green_job
	qui gen n_non_green_job 	= pollutant_sector 	* non_green_job
		
		
	* Estimations
	foreach v of varlist g_green_job g_non_green_job n_green_job n_non_green_job {
		    
		qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `margins' ("LAC") ("`year'") ("`v'") ("`p_`v''")
	}
		
} // Close loop year


postclose `margins'
use `aux', clear
destring, replace

* Organizing database
qui replace Prob = Prob * 100
reshape wide Prob, i(Country Year) j(Est) string
ren Prob* *
ren g_* *_g
ren n_* *_n
drop Country
order Year green_* non_green_*

* Figure 7 – Jobs in green and non-green occupations and sectors in LAC 2010-2019
* Labels and categories
la var Year 			"Year"
la var green_job_g 		"Green Occ. in Green Sectors"
la var green_job_n 		"Green Occ. in Non-green Sectors"
la var non_green_job_g 	"Non-green Occ. in Green Sectors"
la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

* Save results
compress
sort Year
export excel using "${figure_7}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

/*==============================================================================================
  - END
==============================================================================================*/