
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				11/15/2021
Last update: 		05/02/2024
================================================================================================

REGRESSIONS.DO

Description: This dofile estimates various sets of green jobs regressions using circa 2019.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - Call and organize data
==============================================================================================*/

* Load circa 2019
use "$sedlac\circa_2019.dta", clear

* Rounding weight
qui replace pondera = round(pondera)
		
* REMINDER: Always filter for coherent households.
qui cap keep if cohh==1 & ipcf!=.
qui cap keep if ipcf!=. // For those without cohh	
		
* Demographics
cap drop mujer 
cap drop rural 
cap drop less_pri
cap drop prim
cap drop sec
cap drop ter
gen n = 1
gen mujer = !hombre
gen rural = !urbano
gen less_pri = inlist(nivel,0,1)
gen prim = inlist(nivel,2,3)
gen sec = inlist(nivel,4,5)
gen ter = inlist(nivel,6)
gen edad2 = edad^2
		
* Economic sector (according to GHG emissions). In some cases sector1d is missing, then create missing variables.
qui count if sector1d != .
if r(N) != 0 { 
	gen cross_sector1 = (inrange(sector1d,1,2))	// Agriculture, hunting, forestry and fishing
	gen cross_sector2 = sector1d == 3			// Mining and quarrying
	gen cross_sector3 = inlist(sector1d,4,6) 	// Manufacturing, Construction & Industrial processes
	gen cross_sector4 = sector1d == 5			// Electricity, gas and water supply
	gen cross_sector5 = sector1d == 7			// Wholesale and retail trade
	gen cross_sector6 = sector1d == 9			// Transport, storage and communications
	gen cross_sector7 = sector1d == 8			// Hotels and restaurants
	gen cross_sector8 = sector1d == 10			// Financial intermediation
	gen cross_sector9 = sector1d == 11			// Real estate, renting and business activities
	gen cross_sector10 = sector1d == 12			// Public administration and defence
	gen cross_sector11 = sector1d == 13			// Education
	gen cross_sector12 = sector1d == 14			// Health and social work
	gen cross_sector13 = sector1d == 15			// Other community, social and personal service activities
	gen cross_sector14 = sector1d == 16			// Activities of private households as employers
}
else { // Some countries don't have sector defined (BOL 2000)
	forvalues s = 1/14 {
		gen cross_sector`s' = .
	}
}
		
/* Clean/Dirty sectors classification
sector 1 pollutant
sector 2 pollutant, green for CRI for years 2015/2018
sector 3 pollutant
sector 4 pollutant
sector 5 green
sector 6 pollutant
sector 7 green
sector 8 pollutant, green for ARG 2006, 2008/2014, 2017/2018 and CRI 2012
sector 9 green, pollutant for ARG 2006, 2008/2014, 2017/2018 and CRI 2012, 2015/2018
sector 10 green
sector 11 green
sector 12 green
sector 13 pollutant
sector 14 green
*/
		
egen pollutant_sector = rowtotal(cross_sector1-cross_sector4 cross_sector6 cross_sector8 cross_sector13)
egen green_sector = rowtotal(cross_sector5 cross_sector7 cross_sector9-cross_sector12 cross_sector14)	

* Merge with green jobs probabilities
ren isco08_2d isco_2d
tostring isco_2d, replace force
merge m:1 isco_2d using "${base_out_7}", keep(1 3) keepusing(prob_new_emerging_2d prob_enhanced_skills_2d prob_increased_demand_2d) nogenerate
	
* Green jobs classification
ren prob_* *
qui egen green_job = rowtotal(new_emerging_2d enhanced_skills_2d increased_dem), missing // Green Jobs
qui gen non_green_job 	= 1 				- green_job
qui gen g_green_job		= green_sector		* green_job
qui gen n_green_job 	= pollutant 		* green_job
qui gen g_non_green_job = green_sector 		* non_green_job
qui gen n_non_green_job = pollutant_sector 	* non_green_job

* Log labor income (dependant variable)
gen l_ila_ppp11 = log(ila_ppp11)
gen l_ilaho_ppp11 = log(ilaho_ppp11)

* Country numeric (for FE)
encode country, gen (country_code)

* Labels 
la var l_ilaho_ppp11 		"Log Hourly Labor Income PPP 2011" 
la var new_emerging_2d 		"New Emerging" 
la var enhanced_skills_2d 	"Enhanced Skills" 
la var increased_demand_2d 	"Increased Demand" 
la var green_job 			"Green Occupations" 
la var non_green_job 		"Non-green Job" 
la var g_green_job 			"Green Occ. in Green Sectors" 
la var n_green_job 			"Green Occ. in Non-green Sectors" 
la var g_non_green_job 		"Non-green Occ. in Green Sectors" 
la var n_non_green_job 		"Non-green Occ. in Non-green Sectors" 
la var sec 					"Complete Secondary" 
la var ter 					"Complete Tertiary" 
la var mujer 				"Female" 
la var rural 				"Rural" 
la var edad2 				"Age-Square"

* Table 8 – Green jobs and labor income in LAC, circa 2019
estimates clear

* 1)	Green Jobs all - Hourly income with gender control
xi: reg l_ilaho_ppp11 green_job sec ter edad edad2 rural mujer i.country_code [pw=pondera] if ocupado == 1 & inrange(edad,15,64), vce(r)
outreg2 using "${table_8}", label replace
	
* 2)	Green Jobs types - Hourly income with gender control
xi: reg l_ilaho_ppp11 new_emerging_2d enhanced_skills_2d increased_demand_2d sec ter edad edad2 rural mujer i.country_code [pw=pondera] if ocupado == 1 & inrange(edad,15,64), vce(r)
outreg2 using "${table_8}", label append

* 3)	 Green Jobs Green Sectors - Hourly income with gender control
xi: reg l_ilaho_ppp11 g_green_job g_non_green_job n_green_job sec ter edad edad2 rural mujer i.country_code [pw=pondera] if ocupado == 1 & inrange(edad,15,64), vce(r)
outreg2 using "${table_8}", label append

* Erasing txt output files
capture erase "${output}\Table_8.txt"

/*==============================================================================================
  - END
==============================================================================================*/