
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

PROCESS_ENVIRONMENTAL_VARIABLES.DO

Description: Process the green growth indicators database from OECD stats and climate change variables from WDI, and merge them with the green employment database from ILO (at levels).

==============================================================================================*/


/*==============================================================================================
 	1 - OECD: Green Growth Indicators
==============================================================================================*/

* Loading the Green Growth Indicators database, OECD stats
import excel using "${base_in_17}", clear firstrow

* Storing varnames in varlabels and sequentially numerating variables
local i = 1
foreach v of var A-EZ {
	la var `v' "`=`v'[1]'"
	replace `v'="" in 1
	rename `v' var`i'
	loc ++i
	}
drop in 1
destring _all, replace

* Renaming identification variables and other important variables
rename var1 country
rename var2 year
rename var96 sh_envtech_cnt
rename var97 ra_envtech
rename var98 sh_envtech_ww
rename var99 envtech_pc

* Expressing relevant variables as shares
foreach var of varlist sh_envtech_cnt sh_envtech_ww {
	replace `var' = `var'/100
	}

* Filling out country names for all years
replace country=country[_n-1] if country==""

* Saving as a temporal database
sort country year
tempfile oecd
save `oecd', replace


/*==============================================================================================
 	2 - OECD: Environmental Policy Stringency
==============================================================================================*/

* Loding the environmental policy stringency database, index from OECD stats
import excel using "${base_in_18}", clear firstrow

* Renaming and converting year to numeric format
rename *, lower
rename environmentalpolicystringency epol_stringency
destring year, replace

* Filling out country names for all years
replace country=country[_n-1] if country==""

* Merging with the OECD temporal database
sort country year
merge country year using `oecd'
ta _merge
drop _merge

* Saving as a temporal database
sort country year
save `oecd', replace


/*==============================================================================================
 	3 - OECD: Environmentally Related Tax Revenue
==============================================================================================*/

* Loading the environmentally related tax revenue database, from OECD stats
import excel using "${base_in_19}", clear firstrow

* Renaming and converting year to numeric format
rename *, lower
rename taxrevenueofgdpalltaxb erel_tax_revenue
destring year, replace

* Filling out country names for all years
replace country=country[_n-1] if country==""

* Merging with the OECD temporal database
sort country year
merge country year using `oecd'
ta _merge
drop _merge

* Saving as a temporal database
sort country year
save `oecd', replace


/*==============================================================================================
 	4 - OECD: Trade in Environmentally Related Goods
==============================================================================================*/

* Loading the environmentally related goods database, from OECD stats
import delimited using "${base_in_20}", clear

* Keeping relevant variables
keep country year hs environmentalmedium measure value

* Sorting
sort measure country year hs environmentalmedium
order measure country year hs environmentalmedium

* Adding up exports and imports for all goods and for each environmental medium, by country and year
egen gexp = sum(value) if measure=="EXP_VALUE", by(country year)
egen gimp = sum(value) if measure=="IMP_VALUE", by(country year)

* Keeping only one observation by country and year
keep country year gexp gimp
duplicates drop
egen green_exports = sum(gexp), by(country year) missing
label var green_exports "Export value of all environmentally related goods in every environmental medium"
egen green_imports = sum(gimp), by(country year) missing
label var green_imports "Import value of all environmentally related goods in every environmental medium"
drop gexp gimp
duplicates drop

* Merging with the OECD temporal database
sort country year
merge country year using `oecd'
ta _merge
drop _merge


/*==============================================================================================
 	5 - Merging OECD with ILO data
==============================================================================================*/

* Changing OECD country names to match ILO
replace country="Czechia" 				if country=="Czech Republic"
replace country="Korea, Republic of" 	if country=="Korea"
replace country="Slovakia"				if country=="Slovak Republic"
replace country="Cape Verde" 			if country=="Cabo Verde"
replace country="Curaçao" 				if country=="Curacao"
replace country="Russian Federation" 	if country=="Russia"

* Merging with ILO green employment and wages database (in levels)
sort country year
merge country year using "${base_out_11}"
ta _merge
drop _merge

* Saving
sort country year
save "${base_out_12}", replace


/*==============================================================================================
 	6 - Merging with Environmental Variables and WDI GDP Data
==============================================================================================*/

* Loading WDI database containing environmental variables
import excel using "${base_in_21}", clear first

* Renaming variables with misloaded names  
rename J PM25pollutionpopulationexpo2
rename K PM25pollutionpopulationexpo3
rename Q CO2emissionsfromgaseousfuel2
rename S CO2emissionsfromliquidfuelc2
rename X CO2emissionsfromsolidfuelco2
rename AN Adjustedsavingscarbondioxide2
rename AO Adjustedsavingscarbondioxide3
rename AS Nitrousoxideemissionschang2
rename AT Othergreenhousegasemissions2
rename AU Totalgreenhousegasemissions2
rename AV Agriculturalmethaneemissions2
rename AX Adjustedsavingsparticulateem2
rename AZ Adjustednetsavingsincluding2
rename BB Adjustednetsavingsexcluding2

* Dropping last empty rows
drop if CountryCode==""

* Saving as a temporal database
tempfile wdi
sort CountryCode TimeCode
save `wdi', replace

* Loading countries classification by income level database (WB) and merging it with WDI
import excel using "${base_in_22}", clear first
rename Code CountryCode
sort CountryCode
merge CountryCode using `wdi'
ta _merge
drop if _merge==1
drop _merge
sort CountryName TimeCode
save `wdi', replace

* Loading WDI GDP database
import excel using "${base_in_23}", clear first

* Dropping last empty rows 
drop if CountryCode==""

* Merging with WDI environmental variables
sort CountryName TimeCode
merge CountryName TimeCode using `wdi'
ta _merge
drop _merge

* Dropping unnecessary variables
drop TimeCode 

* Renaming variables to be used and putting them first
rename CountryName country
rename CountryCode cnt
rename Time year
rename CO2emissionskgper2010USo co2emissions
rename PM25airpollutionmeanannual airpollution_exposure
rename PM25airpollutionpopulation airpollution_excess
rename GDPcurrentUSNYGDPMKTPC gdp_usd
order country cnt year co2emissions airpollution_exposure airpollution_excess gdp_usd

* Replacing double missing as empty missing and converting to numeric variables
foreach var of varlist co2emissions-Adjustednetsavingsexcluding2 {
	replace `var' = "" if `var' == ".."
	destring `var', replace
	}

* Population exposed to excess of air pollution as a share
replace airpollution_excess = airpollution_excess/100

* Changing WDI country names to match ILO
replace country="Bahamas" 							if country=="Bahamas, The"
replace country="Cape Verde" 						if country=="Cabo Verde"
replace country="China (People's Republic of)" 		if country=="China"
replace country="Congo" 							if country=="Congo, Dem. Rep."
replace country="Curaçao" 							if country=="Curacao"
replace country="Czechia" 							if country=="Czech Republic"
replace country="Côte d'Ivoire" 					if country=="Cote d'Ivoire"
replace country="Democratic Republic of the Congo" 	if country=="Congo, Rep."
replace country="Egypt" 							if country=="Egypt, Arab Rep."
replace country="Gambia" 							if country=="Gambia, The"
replace country="Iran, Islamic Republic of" 		if country=="Iran, Islamic Rep."
replace country="Korea, Republic of" 				if country=="Korea, Rep."
replace country="Kyrgyzstan" 						if country=="Kyrgyz Republic"
replace country="Lao People's Democratic Republic" 	if country=="Lao PDR"
replace country="Micronesia, Federated States of" 	if country=="Micronesia, Fed. Sts."
replace country="Occupied Palestinian Territory" 	if country=="West Bank and Gaza"
replace country="Saint Lucia" 						if country=="St. Lucia"
replace country="Slovakia" 							if country=="Slovak Republic"
replace country="Venezuela" 						if country=="Venezuela, RB"
replace country="Viet Nam" 							if country=="Vietnam"

* Sorting and merging with ILOSTAT + OECD database
sort country year
merge country year using "${base_out_12}"
ta _merge
drop _merge

* Saving
sort country year
save "${base_out_12}", replace


/*==============================================================================================
 	7 - Merging with WDI Control Variables
==============================================================================================*/

* Loading WDI database with control variables
import excel using "${base_in_24}", clear first

* Renaming variables 
rename CountryName country
rename CountryCode cnt
rename Time year
rename Educationalattainmentatleast prop_college_tot
rename F prop_college_male
rename G prop_tertiary_male
rename H prop_tertiary_tot
rename Laborforcewithadvancededucat prop_advancededu_tot
rename J prop_advancededu_male
rename Employmenttopopulationratio emp_rate_male
rename L emp_rate_tot2
rename M emp_rate_tot
rename N emp_rate_male2
rename Employmentinindustryoftot sh_emp_ind_tot
rename Employmentinindustrymale  sh_emp_ind_male

* Dropping unnecessary variables 
drop TimeCode 

* Dropping last empty rows
drop if cnt==""

* Sorting
order country cnt year prop_college_tot prop_college_male prop_tertiary_tot prop_tertiary_male prop_advancededu_tot prop_advancededu_male emp_rate_tot emp_rate_male emp_rate_tot2 emp_rate_male2 sh_emp_ind_tot sh_emp_ind_male

* Replacing double missing as empty missing and converting to numeric variables
foreach var of varlist prop_college_tot- sh_emp_ind_male {
	replace `var' = "" if `var' == ".."
	destring `var', replace
	}

* Expressing variables as shares instead of 0-100 porcentages
foreach var of varlist prop_college_tot- sh_emp_ind_male{
	replace `var' = `var'/100
	}

* Changing WDI country names to match ILO
replace country="Bahamas" 							if country=="Bahamas, The"
replace country="Cape Verde" 						if country=="Cabo Verde"
replace country="China (People's Republic of)" 		if country=="China"
replace country="Congo" 							if country=="Congo, Dem. Rep."
replace country="Curaçao" 							if country=="Curacao"
replace country="Czechia" 							if country=="Czech Republic"
replace country="Côte d'Ivoire" 					if country=="Cote d'Ivoire"
replace country="Democratic Republic of the Congo" 	if country=="Congo, Rep."
replace country="Egypt" 							if country=="Egypt, Arab Rep."
replace country="Gambia" 							if country=="Gambia, The"
replace country="Iran, Islamic Republic of" 		if country=="Iran, Islamic Rep."
replace country="Korea, Republic of" 				if country=="Korea, Rep."
replace country="Kyrgyzstan" 						if country=="Kyrgyz Republic"
replace country="Lao People's Democratic Republic" 	if country=="Lao PDR"
replace country="Micronesia, Federated States of" 	if country=="Micronesia, Fed. Sts."
replace country="Occupied Palestinian Territory" 	if country=="West Bank and Gaza"
replace country="Saint Lucia" 						if country=="St. Lucia"
replace country="Slovakia" 							if country=="Slovak Republic"
replace country="Venezuela" 						if country=="Venezuela, RB"
replace country="Viet Nam" 							if country=="Vietnam"

* Sorting and merging with ILOSTAT + OECD + rest WDI database
sort country year
merge country year using "${base_out_12}"
ta _merge
drop _merge

* Trade green as a share of GDP
gen green_exports_gdp = green_exports / gdp_usd
label var green_exports_gdp "Export value of all environmentally related goods / GDP"
gen green_imports_gdp = green_imports / gdp_usd
label var green_imports_gdp "Import value of all environmentally related goods / GDP"

* Emissions per worker (WDI)
gen porc_15mas  = var150 + var151
gen pobla_15mas = (porc_15mas/100)*(var148*1000)
gen emp_tot = emp_rate_tot*pobla_15mas
gen emissions_per_worker_wdi = (CO2emissionsktENATMCO2E*1000)/emp_tot
label var emissions_per_worker_wdi "CO2 emissions (tonnes) per worker (wdi)"
drop porc_15mas pobla_15mas emp_tot

* Emissions per worker (ILO)
gen emissions_per_worker_ilo = (CO2emissionsktENATMCO2E*1000)/(emp_tot_cnt*1000)
label var emissions_per_worker_ilo "CO2 emissions (tonnes) per worker (ilo)"

* Sorting
sort country year
save "${base_out_12}", replace

/*==============================================================================================
  - END
==============================================================================================*/