
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

ENVIRONMENTAL_REGRESSIONS.DO

Description: Runs regressions of green employment on environmental variables.

==============================================================================================*/


/*==============================================================================================
 	1 - Regressions in level
==============================================================================================*/

* Loading green levels database
use "${base_out_12}", clear

* Setting as a panel
egen id = group(country)
xtset id year

* Log of per capita gdp
rename lgdp_pc lgdp_pc_wdi
gen lgdp_pc = log(GDPpercapitaPPPconstant20)
label var lgdp_pc "log (GDP per capita, PPP (constant 2017 international $))"

* Log of GHG emissions
gen lghgemissions = log(Totalgreenhousegasemissions)
label var lghgemissions "log (Total greenhouse gas emissions (kt of CO2 equivalent))"

* Ratio of employment and wages green/non-green
gen emp_green_non_green = prop_green / prop_non_green

* Variable indicating unbalanced sample with at least 2 available years per country
	* Identifying observations with green jobs + dependent variable data 
	gen complete = (lgdp_pc!=. & prop_green!=.)
	* Number of years available at the country level to perform the regression using the mentioned dependent variable
	egen ncomplete=sum(complete), by(country)
	* Identifying countries with at least 2 available years for the regression included in the country-level unbalanced panel
	gen unbalanced = (ncomplete>=2)

* Variable indicating balanced sample with complete data for 2011-2019 and for green jobs and GDP
	* Number of years available at the country level between 2011-2019
	egen nyears=sum(complete) if year>=2011 & year<=2019, by(country)
	* Identifying countries with at least 2 available years for the regression included in the country-level unbalanced panel
	gen balanced = (nyears==9)

* Regressions 
foreach var of varlist prop_green prop_new_emerging prop_enhanced_skills prop_increased_demand prop_non_green prop_rival prop_other emp_green_non_green lghgemissions {
	* Table A4.a. Fixed effects regression of green jobs and GHG emissions on economic development, unbalanced panel 2001-2020.
	xtreg `var' lgdp_pc if unbalanced==1, fe robust
	if "`var'"=="prop_green" outreg2 using "${table_a4_a}", replace label nocons
	if "`var'"!="prop_green" outreg2 using "${table_a4_a}", append label nocons
	* Table A4.b. Fixed effects regression of green jobs and GHG emissions on economic development, balanced panel 2011-2019.	
	xtreg `var' lgdp_pc if balanced==1, fe robust
	if "`var'"=="prop_green" outreg2 using "${table_a4_b}", replace label nocons
	if "`var'"!="prop_green" outreg2 using "${table_a4_b}", append label nocons
	}

* Erasing txt output files
capture erase "${output}\Table_A4_a.txt" 
capture erase "${output}\Table_A4_b.txt"

/*==============================================================================================
  - END
==============================================================================================*/