
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

DESCRIPTIVE_SEDLAC.DO

Description: Generate descriptive statistics based on SEDLAC.

==============================================================================================*/


/*==============================================================================================
	1 - Database Structure
==============================================================================================*/

clear all
tempname margins
tempfile aux
postfile `margins' str30(Country Digits Est Prob) using `aux', replace


/*==============================================================================================
	2 - Workers per sector and green job classification
==============================================================================================*/
	
* Load circa 2019
use "$sedlac\circa_2019.dta", clear
keep if inlist(country,"DOM","ECU","HND","PAN","PER","SLV","URY")
	
* REMINDER: Always filter for coherent households.
qui cap keep if cohh==1 & ipcf_ppp11!=.
qui cap keep if ipcf_ppp11!=. // For those without cohh
	
* Bucle por dígitos del isco08
forvalues d=1/4 {
	
	preserve
	
		* Merge with green jobs probabilities
		gen isco08_1d = int(isco08_2d/10)
		capture gen isco08_`d'd = .
		ren isco08_`d'd isco_`d'd
		qui tostring isco_`d'd, replace force
		qui merge m:1 isco_`d'd using "${path}\Data\own production\green_occ_isco08_`d'd", keep(1 3) keepusing(prob_new_emerging_`d'd prob_enhanced_skills_`d'd prob_increased_demand_`d'd) nogenerate
			
		* Green jobs classification
		ren prob_* *
		qui egen green_job = rowtotal(new_emerging enhanced_skills increased_dem), missing // Green Jobs

		* Estimations
		foreach v of varlist green_job new_emerging enhanced_skills increased_demand {
				
			* Total Workers
			qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64)
			loc p_`v'=r(mean)
			post `margins' ("LAC") ("`d'") ("`v'") ("`p_`v''")
			
			* Country-level
			local countries DOM ECU HND PAN PER SLV URY
			foreach country of local countries {

				qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64) & country == "`country'"
				loc p_`v'=r(mean)
				post `margins' ("`country'") ("`d'") ("`v'") ("`p_`v''")
		
			}
				
		}
		
	restore
}

postclose `margins'
use `aux', clear
destring, replace

* Organizing database
replace Prob = Prob * 100
replace Est = substr(Est, 1, length(Est) - 3) if Est != "green_job"
reshape wide Prob, i(Country Est) j(Digits)
ren Prob* d_*
order Country Est d_1 d_2 d_3 d_4 

la var Country "Country ISO Code"
la var d_1 "1 digit"
la var d_2 "2 digits"
la var d_3 "3 digits"
la var d_4 "4 digits"


/*==============================================================================================
	3 - Figures
==============================================================================================*/

* Table 9 - Percentage of workers in green occupations in LAC circa 2019 - by country and ISCO classification (digit level).

* (a) New and Emerging
preserve
	keep if Est == "new_emerging"
	sort d_1
	export excel Country d_* using "${table_9a}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore

* (b) Enhanced Skills
preserve
	keep if Est == "enhanced_skills"
	sort d_1
	export excel Country d_* using "${table_9b}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore

* (c) Increased Demand
preserve
	keep if Est == "increased_demand"
	sort d_1
	export excel Country d_* using "${table_9c}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore

* (d) Green Jobs
preserve
	keep if Est == "green_job"
	sort d_1
	export excel Country d_* using "${table_9d}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)
restore

/*==============================================================================================
  - END
==============================================================================================*/