
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				19/03/2024
Last update: 		05/02/2024
================================================================================================

DECOMPO_EMISSIONS.DO

Description: Perform a decomposition of the change in emissions per worker between sectors and within sectors (MacMillan & Rodrik, 2011).

==============================================================================================*/


/*==============================================================================================
	1 - Total and sectoral employment bycountry-year
==============================================================================================*/

clear
tempfile employment
save `employment', emptyok replace 

* Latin America countries to include in the analysis
local countries ARG BRA CHL COL CRI MEX PER

foreach country of local countries { // Open loop countries
	
	foreach year of numlist 2005 2018 { // Open loop year
		
		* Loading the data
		
		di in red "`country' - `year'"
				
		if "`country'" == "ARG" qui dlw, country("`country'") year(`year') type(sedlac) period(s2) mod(lab) clear // We use period S2 for Argentina
		
		else if ("`country'" == "BRA" & `year' == 2018) qui dlw, country("`country'") year(`year') type(sedlac) mod(lab) survey(pnadc) clear // BRA has 2 surveys between 2012 and 2015, we use PNADC.
		
		else if ("`country'" == "CHL" & `year'== 2005) qui dlw, country("`country'") year(2006) type(sedlac) mod(lab) clear
		
		else if ("`country'" == "CHL" & `year'== 2018) qui dlw, country("`country'") year(2017) type(sedlac) mod( lab) clear
		
		else if ("`country'" == "MEX" & `year'== 2005) qui dlw, country("`country'") year(2006) type(sedlac) mod(lab) clear
	
		else qui dlw, country("`country'") year(`year') type(sedlac) mod(lab) clear

		* Preserves relevant variables
		keep pais year ocupado sector1d pondera

		* Keeping workers with non-missing economic sector
		qui keep if ocupado==1 & sector1d!=.

		* Total workers by sector
		collapse (sum) pondera, by(pais year sector1d)
		
		* Save the information
		qui append using `employment'
		qui save `employment', replace

	} // Close loop year
	
} // Close loop countries

use `employment', clear

* Rename countries and variables
replace pais =  upper(pais)
ren pais country

* Economic sector (according to GHG emissions). In some cases sector1d is missing, then create missing variables.
gen 	cross_sector = 1  if (inrange(sector1d,1,2))	// Agriculture, hunting, forestry and fishing
replace cross_sector = 2  if sector1d == 3			// Mining and quarrying
replace cross_sector = 3  if inlist(sector1d,4,6) 	// Manufacturing, Construction & Industrial processes
replace cross_sector = 4  if sector1d == 5			// Electricity, gas and water supply
replace cross_sector = 5  if sector1d == 7			// Wholesale and retail trade
replace cross_sector = 6  if sector1d == 9			// Transport, storage and communications
replace cross_sector = 7  if sector1d == 8			// Hotels and restaurants
replace cross_sector = 8  if sector1d == 10			// Financial intermediation
replace cross_sector = 9  if sector1d == 11			// Real estate, renting and business activities
replace cross_sector = 10 if sector1d == 12			// Public administration and defence
replace cross_sector = 11 if sector1d == 13			// Education
replace cross_sector = 12 if sector1d == 14			// Health and social work
replace cross_sector = 13 if sector1d == 15			// Other community, social and personal service activities
replace cross_sector = 14 if sector1d == 16			// Activities of private households as employers
drop if sector1d == 17

* Number of workers
egen nworkers=sum(pondera), by(cross_sector country year)

* Keep only one observation by country-year-sector
keep country year cross_sector nworkers
duplicates drop


/*==============================================================================================
	2 - Merging with Emissions data
==============================================================================================*/

* Loading emissions data
preserve
	use "${base_out_3}", clear
	sort country year cross_sector
	tempfile emissions
	save `emissions', replace
restore

* Merging with emissions data
sort country year cross_sector
merge 1:1 country year cross_sector using `emissions', keep(3) nogen

* Green sector identifier
gen 	green = 0
replace green = 1 if inlist(cross_sector,5,7,9,10,11,12,14)

* Replace year by 2005 and 2018 in proxy cases (CHL y MEX)
replace year = 2005 if year==2006
replace year = 2018 if year==2017


/*==============================================================================================
	3 - Decompositions
==============================================================================================*/

* Aggregate data at the regional level
collapse (sum) nworkers emissions (mean) green, by(year cross_sector)
gen country = "LAC"
order country

* Set database as panel
egen id=group(cross_sector)
xtset id year, delta(13)
order country year id cross_sector green

* Workers by year
egen N = sum(nworkers), by(country year)

* Employment share by sector-year
gen theta = nworkers/N

* Change in sectoral employment share between 2005 and 2018
gen dtheta = d.theta

* Sectoral employment share for the initial year
gen ltheta = l.theta

* Sectoral emissions per worker (tons)
gen p = emissions*1000000000/ nworkers

* Emissions per worker in all sectors
egen P = sum(emissions*1000000000), by(country year)
replace P = P/N

* Change in emissions per worker, total and by sector
gen dp = d.p
gen dP = d.P

* Sectoral emissions per worker for the initial year
gen lp = l.p

* Figure 8 - Decomposition of the change in GHG emissions (tn.) per worker by sector in LAC, 2005-2018

* Keep variables computed for the last year
keep if year==2018

* Components within, between and total
gen within  = ltheta*dp
gen between = p*dtheta
gen total   = within + between

* Checking decomposition is properly working 
sum total
di r(sum)
sum dP
di r(mean)

* Preserving relevantes variables
keep cross_sector green within between total

* All sectors in the last row
set obs 16
replace cross_sector = 0 in 16
foreach var of varlist within between total {
	sum `var'
	replace `var' = r(sum) in 16
}

* Exporting LAC decomposition results
export excel cross_sector green within between total using "${figure_8}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

/*==============================================================================================
  - END
==============================================================================================*/