
/*==============================================================================================
Project:			Measuring Green Jobs: A New Database for Latin America and other Regions

Authors:			Kelly Y. Montoya, Emmanuel J. Vazquez, & Hernan J. Winkler
e-mails:			kmontoyamunoz@worldbank.org, evazquez@cedlas.org, hwinkler@worldbank.org
Institution:		World Bank Group - ELCPV

Date:				04/19/2024
Last update: 		05/02/2024
================================================================================================

A_GREEN_JOBS_CIRCA_2019.DO

Description: This dofile calculates estimates of green jobs for LAC region and by country, using circa 2019 and using a different sectoral classification.

* Source: SEDLAC Harmonized databases from dataliweb.
* Data version Apr 19, 2024.

==============================================================================================*/


/*==============================================================================================
	1 - Database Structure
==============================================================================================*/

clear all
tempname circa2019
tempfile aux
postfile `circa2019' str30(Country Year Aggregate Est Prob) using `aux', replace


/*==============================================================================================
	2 - Workers per sector and green job classification
==============================================================================================*/

* Load circa 2019
use "$sedlac\circa_2019.dta", clear
	
* Rounding weight
qui replace pondera = round(pondera)
		
* REMINDER: Always filter for coherent households.
qui cap keep if cohh==1 & ipcf_ppp11!=.
qui cap keep if ipcf_ppp11!=. // For those without cohh

* Income quintile 
gen quintile = .
levelsof country, local(countries)
foreach country of local countries {
	xtile quintile_`country' = ipcf [fw=pondera] if country == "`country'", n(5)
	replace quintile = quintile_`country' if country == "`country'"
	cap drop quintile_`country'
}
qui tab quintile, gen (quintile_)
drop quintile
		
* Economic sector (according to GHG emissions). In some cases sector1d is missing, then create missing variables.
qui count if sector1d != .
if r(N) != 0 { 
	gen cross_sector1  = (inrange(sector1d,1,2))	// Agriculture, hunting, forestry and fishing
	gen cross_sector2  = sector1d == 3				// Mining and quarrying
	gen cross_sector3  = inlist(sector1d,4,6) 		// Manufacturing, Construction & Industrial processes
	gen cross_sector4  = sector1d == 5				// Electricity, gas and water supply
	gen cross_sector5  = sector1d == 7				// Wholesale and retail trade
	gen cross_sector6  = sector1d == 9				// Transport, storage and communications
	gen cross_sector7  = sector1d == 8				// Hotels and restaurants
	gen cross_sector8  = sector1d == 10				// Financial intermediation
	gen cross_sector9  = sector1d == 11				// Real estate, renting and business activities
	gen cross_sector10 = sector1d == 12				// Public administration and defence
	gen cross_sector11 = sector1d == 13				// Education
	gen cross_sector12 = sector1d == 14				// Health and social work
	gen cross_sector13 = sector1d == 15				// Other community, social and personal service activities
	gen cross_sector14 = sector1d == 16				// Activities of private households as employers
}
else { // Some countries don't have sector defined (BOL 2000)
	forvalues s = 1/14 {
		gen cross_sector`s' = .
	}
}
		
/* Clean/Dirty sectors classification
All services sectors are green, and non-services sectors (agriculture and industry) are non-green
- Pollutant: 1 - 4
- Green: 5 - 14
*/
		
egen pollutant_sector = rowtotal(cross_sector1-cross_sector4)
egen green_sector = rowtotal(cross_sector5-cross_sector14)
		
* Merge with green jobs probabilities
ren isco08_2d isco_2d
tostring isco_2d, replace force
merge m:1 isco_2d using "${base_out_7}", keep(1 3) keepusing(prob_new_emerging_2d prob_enhanced_skills_2d prob_increased_demand_2d) nogenerate
		
* Green jobs classification
ren prob_* *
qui egen green_job = rowtotal(new_emerging_2d enhanced_skills_2d increased_dem), missing // Green Jobs
qui gen non_green_job = 1 - green_job
qui gen g_green_job = green_sector * green_job
qui gen n_green_job = pollutant * green_job
qui gen g_non_green_job = green_sector * non_green_job
qui gen n_non_green_job = pollutant_sector * non_green_job
		
* Employment by sector and green jobs classification
foreach v of varlist g_green_job g_non_green_job n_green_job n_non_green_job {
	
	di in red "`v'"
	
	* Total Workers
	qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64)
	loc p_`v'=r(mean)
	post `circa2019' ("LAC") ("2019") ("Total") ("`v'") ("`p_`v''")
			
	* Income
	foreach v2 of varlist quintile_1 quintile_2 quintile_3 quintile_4 quintile_5 {
	    qui sum `v' [w=pondera] if `v2'==1 & inrange(edad,15,64)
		loc p_`v'=r(mean)
		post `circa2019' ("LAC") ("2019") ("`v2'") ("`v'") ("`p_`v''")
	}
			
			
	* Country-level
	local countries ARG BOL BRA CHL COL CRI DOM ECU GTM HND MEX NIC PAN PER SLV URY
	foreach country of local countries {
	    
		qui sum year if country == "`country'"
		loc year=r(mean)
		
		* Total Workers
		qui sum `v' [w=pondera] if ocupado==1 & inrange(edad,15,64) & country == "`country'"
		loc p_`v'=r(mean)
		post `circa2019' ("`country'") ("`year'") ("Total") ("`v'") ("`p_`v''")
				
	}
}

* Compile results
postclose `circa2019'
use `aux', clear
destring, replace

* Organizing database
replace Prob = Prob * 100
reshape wide Prob, i(Country Year Aggregate) j(Est) string
ren Prob* *
ren g_* *_g
ren n_* *_n


/*==============================================================================================
	3 - Figures
==============================================================================================*/

* Figure A3 – Green occupations and green sectors in LAC

preserve

	* Keep only necessary observation and order the database
	keep if Aggregate == "Total"
	keep Country Year green_job_g green_job_n non_green_job_g non_green_job_n
	order Country Year green_* non_green_*

	* Labels and categories
	la var Country 			"Country"
	la var Year 			"Year"
	la var green_job_g 		"Green Occ. in Green Sectors"
	la var green_job_n 		"Green Occ. in Non-green Sectors"
	la var non_green_job_g 	"Non-green Occ. in Green Sectors"
	la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

	* Save results
	compress
	gsort -non_green_job_n
	export excel using "${figure_a3}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore


* Figure A5 – Green and non-green occupations and sectors vs. household income quintiles, LAC 2019
preserve

	* Keep only necessary
	keep if inlist(Aggregate,"quintile_1","quintile_2","quintile_3","quintile_4","quintile_5")
	keep Aggregate green_job_g green_job_n non_green_job_g non_green_job_n

	* Labels and categories
	la var green_job_g 		"Green Occ. in Green Sectors"
	la var green_job_n 		"Green Occ. in Non-green Sectors"
	la var non_green_job_g 	"Non-green Occ. in Green Sectors"
	la var non_green_job_n 	"Non-green Occ. in Non-green Sectors"

	replace Aggregate = "Quintile 1" if Aggregate == "quintile_1"
	replace Aggregate = "Quintile 2" if Aggregate == "quintile_2"
	replace Aggregate = "Quintile 3" if Aggregate == "quintile_3"
	replace Aggregate = "Quintile 4" if Aggregate == "quintile_4"
	replace Aggregate = "Quintile 5" if Aggregate == "quintile_5"

	* Save results
	compress
	order Aggregate green_* non_green_*
	sort Aggregate
	export excel using "${figure_a5}", sheet("Green Jobs Outputs") sheetreplace firstrow(varlabels)

restore

/*==============================================================================================
  - END
==============================================================================================*/